# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/credential.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/credential.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$kaskada/api/v1alpha/credential.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a kaskada/api/v1alpha/shared.proto\"\x16\n\x14GetCredentialRequest\"\xa7\x01\n\x15GetCredentialResponse\x12\x1b\n\tclient_id\x18\x01 \x01(\tR\x08\x63lientId\x12#\n\rclient_secret\x18\x02 \x01(\tR\x0c\x63lientSecret\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\x8e\x01\n\x11\x43redentialService\x12y\n\x03Get\x12).kaskada.api.v1alpha.GetCredentialRequest\x1a*.kaskada.api.v1alpha.GetCredentialResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/v1alpha/credentialBV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,])




_GETCREDENTIALREQUEST = _descriptor.Descriptor(
  name='GetCredentialRequest',
  full_name='kaskada.api.v1alpha.GetCredentialRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=125,
  serialized_end=147,
)


_GETCREDENTIALRESPONSE = _descriptor.Descriptor(
  name='GetCredentialResponse',
  full_name='kaskada.api.v1alpha.GetCredentialResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_id', full_name='kaskada.api.v1alpha.GetCredentialResponse.client_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clientId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='client_secret', full_name='kaskada.api.v1alpha.GetCredentialResponse.client_secret', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='clientSecret', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.GetCredentialResponse.request_details', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=150,
  serialized_end=317,
)

_GETCREDENTIALRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
DESCRIPTOR.message_types_by_name['GetCredentialRequest'] = _GETCREDENTIALREQUEST
DESCRIPTOR.message_types_by_name['GetCredentialResponse'] = _GETCREDENTIALRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetCredentialRequest = _reflection.GeneratedProtocolMessageType('GetCredentialRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCREDENTIALREQUEST,
  '__module__' : 'kaskada.api.v1alpha.credential_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetCredentialRequest)
  })
_sym_db.RegisterMessage(GetCredentialRequest)

GetCredentialResponse = _reflection.GeneratedProtocolMessageType('GetCredentialResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCREDENTIALRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.credential_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetCredentialResponse)
  })
_sym_db.RegisterMessage(GetCredentialResponse)


DESCRIPTOR._options = None

_CREDENTIALSERVICE = _descriptor.ServiceDescriptor(
  name='CredentialService',
  full_name='kaskada.api.v1alpha.CredentialService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=320,
  serialized_end=462,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='kaskada.api.v1alpha.CredentialService.Get',
    index=0,
    containing_service=None,
    input_type=_GETCREDENTIALREQUEST,
    output_type=_GETCREDENTIALRESPONSE,
    serialized_options=b'\202\323\344\223\002\025\022\023/v1alpha/credential',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_CREDENTIALSERVICE)

DESCRIPTOR.services_by_name['CredentialService'] = _CREDENTIALSERVICE

# @@protoc_insertion_point(module_scope)
