# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/materialization.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.api.v1alpha import compute_pb2 as kaskada_dot_api_dot_v1alpha_dot_compute__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from kaskada.prepare.v1alpha import slice_pb2 as kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/materialization.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n)kaskada/api/v1alpha/materialization.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!kaskada/api/v1alpha/compute.proto\x1a kaskada/api/v1alpha/shared.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a#kaskada/prepare/v1alpha/slice.proto\x1a\x17validate/validate.proto\"\xd1\x04\n\x0fMaterialization\x12\x33\n\x12materialization_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x11materializationId\x12:\n\x14materialization_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\x12\x41\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x14\n\x05query\x18\x04 \x01(\tR\x05query\x12<\n\nwith_views\x18\x05 \x03(\x0b\x32\x1d.kaskada.api.v1alpha.WithViewR\twithViews\x12J\n\tredis_a_i\x18\x06 \x01(\x0b\x32,.kaskada.api.v1alpha.Materialization.RedisAIH\x00R\x07redisAI\x12:\n\x06schema\x18\x07 \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaB\x04\xe2\x41\x01\x03R\x06schema\x12;\n\x05slice\x18\x08 \x01(\x0b\x32%.kaskada.prepare.v1alpha.SliceRequestR\x05slice\x1a\x62\n\x07RedisAI\x12\x19\n\x02\x64\x62\x18\x01 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x0f(\x00R\x02\x64\x62\x12\x1b\n\x04host\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04host\x12\x1f\n\x04port\x18\x03 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00R\x04portB\r\n\x0b\x64\x65stination\"}\n\x1bListMaterializationsRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xe6\x01\n\x1cListMaterializationsResponse\x12P\n\x10materializations\x18\x01 \x03(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x10materializations\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"W\n\x19GetMaterializationRequest\x12:\n\x14materialization_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\"\xba\x01\n\x1aGetMaterializationResponse\x12N\n\x0fmaterialization\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x0fmaterialization\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"n\n\x1c\x43reateMaterializationRequest\x12N\n\x0fmaterialization\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x0fmaterialization\"\xf8\x01\n\x1d\x43reateMaterializationResponse\x12N\n\x0fmaterialization\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.MaterializationR\x0fmaterialization\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\x12\x39\n\x08\x61nalysis\x18\x03 \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisR\x08\x61nalysis\"Z\n\x1c\x44\x65leteMaterializationRequest\x12:\n\x14materialization_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13materializationName\"s\n\x1d\x44\x65leteMaterializationResponse\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetailsJ\x04\x08\x01\x10\x02\x32\xdf\x05\n\x16MaterializationService\x12\x9e\x01\n\x14ListMaterializations\x12\x30.kaskada.api.v1alpha.ListMaterializationsRequest\x1a\x31.kaskada.api.v1alpha.ListMaterializationsResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1alpha/materializations\x12\xb1\x01\n\x12GetMaterialization\x12..kaskada.api.v1alpha.GetMaterializationRequest\x1a/.kaskada.api.v1alpha.GetMaterializationResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/v1alpha/materializations/{materialization_name=*}\x12\xb2\x01\n\x15\x43reateMaterialization\x12\x31.kaskada.api.v1alpha.CreateMaterializationRequest\x1a\x32.kaskada.api.v1alpha.CreateMaterializationResponse\"2\x82\xd3\xe4\x93\x02,\"\x19/v1alpha/materializations:\x0fmaterialization\x12\xba\x01\n\x15\x44\x65leteMaterialization\x12\x31.kaskada.api.v1alpha.DeleteMaterializationRequest\x1a\x32.kaskada.api.v1alpha.DeleteMaterializationResponse\":\x82\xd3\xe4\x93\x02\x34*2/v1alpha/materializations/{materialization_name=*}BV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_compute__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2.DESCRIPTOR,kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_MATERIALIZATION_REDISAI = _descriptor.Descriptor(
  name='RedisAI',
  full_name='kaskada.api.v1alpha.Materialization.RedisAI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='db', full_name='kaskada.api.v1alpha.Materialization.RedisAI.db', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\032\004\030\017(\000', json_name='db', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='kaskada.api.v1alpha.Materialization.RedisAI.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='host', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='kaskada.api.v1alpha.Materialization.RedisAI.port', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010\032\006\030\377\377\003 \000', json_name='port', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=809,
  serialized_end=907,
)

_MATERIALIZATION = _descriptor.Descriptor(
  name='Materialization',
  full_name='kaskada.api.v1alpha.Materialization',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization_id', full_name='kaskada.api.v1alpha.Materialization.materialization_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='materializationId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='materialization_name', full_name='kaskada.api.v1alpha.Materialization.materialization_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='materializationName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='kaskada.api.v1alpha.Materialization.create_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='createTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query', full_name='kaskada.api.v1alpha.Materialization.query', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_views', full_name='kaskada.api.v1alpha.Materialization.with_views', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='withViews', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redis_a_i', full_name='kaskada.api.v1alpha.Materialization.redis_a_i', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redisAI', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='kaskada.api.v1alpha.Materialization.schema', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slice', full_name='kaskada.api.v1alpha.Materialization.slice', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slice', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MATERIALIZATION_REDISAI, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='destination', full_name='kaskada.api.v1alpha.Materialization.destination',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=329,
  serialized_end=922,
)


_LISTMATERIALIZATIONSREQUEST = _descriptor.Descriptor(
  name='ListMaterializationsRequest',
  full_name='kaskada.api.v1alpha.ListMaterializationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search', full_name='kaskada.api.v1alpha.ListMaterializationsRequest.search', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='search', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='kaskada.api.v1alpha.ListMaterializationsRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\032\005\030\350\007(\000', json_name='pageSize', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='kaskada.api.v1alpha.ListMaterializationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pageToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=1049,
)


_LISTMATERIALIZATIONSRESPONSE = _descriptor.Descriptor(
  name='ListMaterializationsResponse',
  full_name='kaskada.api.v1alpha.ListMaterializationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materializations', full_name='kaskada.api.v1alpha.ListMaterializationsResponse.materializations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materializations', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='kaskada.api.v1alpha.ListMaterializationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nextPageToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.ListMaterializationsResponse.request_details', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1052,
  serialized_end=1282,
)


_GETMATERIALIZATIONREQUEST = _descriptor.Descriptor(
  name='GetMaterializationRequest',
  full_name='kaskada.api.v1alpha.GetMaterializationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization_name', full_name='kaskada.api.v1alpha.GetMaterializationRequest.materialization_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='materializationName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1284,
  serialized_end=1371,
)


_GETMATERIALIZATIONRESPONSE = _descriptor.Descriptor(
  name='GetMaterializationResponse',
  full_name='kaskada.api.v1alpha.GetMaterializationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization', full_name='kaskada.api.v1alpha.GetMaterializationResponse.materialization', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.GetMaterializationResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1374,
  serialized_end=1560,
)


_CREATEMATERIALIZATIONREQUEST = _descriptor.Descriptor(
  name='CreateMaterializationRequest',
  full_name='kaskada.api.v1alpha.CreateMaterializationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization', full_name='kaskada.api.v1alpha.CreateMaterializationRequest.materialization', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1562,
  serialized_end=1672,
)


_CREATEMATERIALIZATIONRESPONSE = _descriptor.Descriptor(
  name='CreateMaterializationResponse',
  full_name='kaskada.api.v1alpha.CreateMaterializationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization', full_name='kaskada.api.v1alpha.CreateMaterializationResponse.materialization', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='materialization', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.CreateMaterializationResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analysis', full_name='kaskada.api.v1alpha.CreateMaterializationResponse.analysis', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='analysis', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1675,
  serialized_end=1923,
)


_DELETEMATERIALIZATIONREQUEST = _descriptor.Descriptor(
  name='DeleteMaterializationRequest',
  full_name='kaskada.api.v1alpha.DeleteMaterializationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='materialization_name', full_name='kaskada.api.v1alpha.DeleteMaterializationRequest.materialization_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='materializationName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1925,
  serialized_end=2015,
)


_DELETEMATERIALIZATIONRESPONSE = _descriptor.Descriptor(
  name='DeleteMaterializationResponse',
  full_name='kaskada.api.v1alpha.DeleteMaterializationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.DeleteMaterializationResponse.request_details', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2017,
  serialized_end=2132,
)

_MATERIALIZATION_REDISAI.containing_type = _MATERIALIZATION
_MATERIALIZATION.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_MATERIALIZATION.fields_by_name['with_views'].message_type = kaskada_dot_api_dot_v1alpha_dot_compute__pb2._WITHVIEW
_MATERIALIZATION.fields_by_name['redis_a_i'].message_type = _MATERIALIZATION_REDISAI
_MATERIALIZATION.fields_by_name['schema'].message_type = kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2._SCHEMA
_MATERIALIZATION.fields_by_name['slice'].message_type = kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2._SLICEREQUEST
_MATERIALIZATION.oneofs_by_name['destination'].fields.append(
  _MATERIALIZATION.fields_by_name['redis_a_i'])
_MATERIALIZATION.fields_by_name['redis_a_i'].containing_oneof = _MATERIALIZATION.oneofs_by_name['destination']
_LISTMATERIALIZATIONSRESPONSE.fields_by_name['materializations'].message_type = _MATERIALIZATION
_LISTMATERIALIZATIONSRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_GETMATERIALIZATIONRESPONSE.fields_by_name['materialization'].message_type = _MATERIALIZATION
_GETMATERIALIZATIONRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_CREATEMATERIALIZATIONREQUEST.fields_by_name['materialization'].message_type = _MATERIALIZATION
_CREATEMATERIALIZATIONRESPONSE.fields_by_name['materialization'].message_type = _MATERIALIZATION
_CREATEMATERIALIZATIONRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_CREATEMATERIALIZATIONRESPONSE.fields_by_name['analysis'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._ANALYSIS
_DELETEMATERIALIZATIONRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
DESCRIPTOR.message_types_by_name['Materialization'] = _MATERIALIZATION
DESCRIPTOR.message_types_by_name['ListMaterializationsRequest'] = _LISTMATERIALIZATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListMaterializationsResponse'] = _LISTMATERIALIZATIONSRESPONSE
DESCRIPTOR.message_types_by_name['GetMaterializationRequest'] = _GETMATERIALIZATIONREQUEST
DESCRIPTOR.message_types_by_name['GetMaterializationResponse'] = _GETMATERIALIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['CreateMaterializationRequest'] = _CREATEMATERIALIZATIONREQUEST
DESCRIPTOR.message_types_by_name['CreateMaterializationResponse'] = _CREATEMATERIALIZATIONRESPONSE
DESCRIPTOR.message_types_by_name['DeleteMaterializationRequest'] = _DELETEMATERIALIZATIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteMaterializationResponse'] = _DELETEMATERIALIZATIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Materialization = _reflection.GeneratedProtocolMessageType('Materialization', (_message.Message,), {

  'RedisAI' : _reflection.GeneratedProtocolMessageType('RedisAI', (_message.Message,), {
    'DESCRIPTOR' : _MATERIALIZATION_REDISAI,
    '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Materialization.RedisAI)
    })
  ,
  'DESCRIPTOR' : _MATERIALIZATION,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Materialization)
  })
_sym_db.RegisterMessage(Materialization)
_sym_db.RegisterMessage(Materialization.RedisAI)

ListMaterializationsRequest = _reflection.GeneratedProtocolMessageType('ListMaterializationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZATIONSREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListMaterializationsRequest)
  })
_sym_db.RegisterMessage(ListMaterializationsRequest)

ListMaterializationsResponse = _reflection.GeneratedProtocolMessageType('ListMaterializationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTMATERIALIZATIONSRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListMaterializationsResponse)
  })
_sym_db.RegisterMessage(ListMaterializationsResponse)

GetMaterializationRequest = _reflection.GeneratedProtocolMessageType('GetMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetMaterializationRequest)
  })
_sym_db.RegisterMessage(GetMaterializationRequest)

GetMaterializationResponse = _reflection.GeneratedProtocolMessageType('GetMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetMaterializationResponse)
  })
_sym_db.RegisterMessage(GetMaterializationResponse)

CreateMaterializationRequest = _reflection.GeneratedProtocolMessageType('CreateMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateMaterializationRequest)
  })
_sym_db.RegisterMessage(CreateMaterializationRequest)

CreateMaterializationResponse = _reflection.GeneratedProtocolMessageType('CreateMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateMaterializationResponse)
  })
_sym_db.RegisterMessage(CreateMaterializationResponse)

DeleteMaterializationRequest = _reflection.GeneratedProtocolMessageType('DeleteMaterializationRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMATERIALIZATIONREQUEST,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteMaterializationRequest)
  })
_sym_db.RegisterMessage(DeleteMaterializationRequest)

DeleteMaterializationResponse = _reflection.GeneratedProtocolMessageType('DeleteMaterializationResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEMATERIALIZATIONRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.materialization_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteMaterializationResponse)
  })
_sym_db.RegisterMessage(DeleteMaterializationResponse)


DESCRIPTOR._options = None
_MATERIALIZATION_REDISAI.fields_by_name['db']._options = None
_MATERIALIZATION_REDISAI.fields_by_name['host']._options = None
_MATERIALIZATION_REDISAI.fields_by_name['port']._options = None
_MATERIALIZATION.fields_by_name['materialization_id']._options = None
_MATERIALIZATION.fields_by_name['materialization_name']._options = None
_MATERIALIZATION.fields_by_name['create_time']._options = None
_MATERIALIZATION.fields_by_name['schema']._options = None
_LISTMATERIALIZATIONSREQUEST.fields_by_name['page_size']._options = None
_GETMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._options = None
_DELETEMATERIALIZATIONREQUEST.fields_by_name['materialization_name']._options = None

_MATERIALIZATIONSERVICE = _descriptor.ServiceDescriptor(
  name='MaterializationService',
  full_name='kaskada.api.v1alpha.MaterializationService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2135,
  serialized_end=2870,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListMaterializations',
    full_name='kaskada.api.v1alpha.MaterializationService.ListMaterializations',
    index=0,
    containing_service=None,
    input_type=_LISTMATERIALIZATIONSREQUEST,
    output_type=_LISTMATERIALIZATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\022\031/v1alpha/materializations',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetMaterialization',
    full_name='kaskada.api.v1alpha.MaterializationService.GetMaterialization',
    index=1,
    containing_service=None,
    input_type=_GETMATERIALIZATIONREQUEST,
    output_type=_GETMATERIALIZATIONRESPONSE,
    serialized_options=b'\202\323\344\223\0024\0222/v1alpha/materializations/{materialization_name=*}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateMaterialization',
    full_name='kaskada.api.v1alpha.MaterializationService.CreateMaterialization',
    index=2,
    containing_service=None,
    input_type=_CREATEMATERIALIZATIONREQUEST,
    output_type=_CREATEMATERIALIZATIONRESPONSE,
    serialized_options=b'\202\323\344\223\002,\"\031/v1alpha/materializations:\017materialization',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteMaterialization',
    full_name='kaskada.api.v1alpha.MaterializationService.DeleteMaterialization',
    index=3,
    containing_service=None,
    input_type=_DELETEMATERIALIZATIONREQUEST,
    output_type=_DELETEMATERIALIZATIONRESPONSE,
    serialized_options=b'\202\323\344\223\0024*2/v1alpha/materializations/{materialization_name=*}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_MATERIALIZATIONSERVICE)

DESCRIPTOR.services_by_name['MaterializationService'] = _MATERIALIZATIONSERVICE

# @@protoc_insertion_point(module_scope)
