# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/shared.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaskada.errdetails.v1alpha import fenl_diagnostics_pb2 as kaskada_dot_errdetails_dot_v1alpha_dot_fenl__diagnostics__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/shared.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n kaskada/api/v1alpha/shared.proto\x12\x13kaskada.api.v1alpha\x1a\x31kaskada/errdetails/v1alpha/fenl_diagnostics.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a\x17validate/validate.proto\"\xa8\x01\n\x08\x41nalysis\x12#\n\rmissing_names\x18\x01 \x03(\tR\x0cmissingNames\x12V\n\x10\x66\x65nl_diagnostics\x18\x02 \x01(\x0b\x32+.kaskada.errdetails.v1alpha.FenlDiagnosticsR\x0f\x66\x65nlDiagnostics\x12\x1f\n\x0b\x63\x61n_execute\x18\x03 \x01(\x08R\ncanExecute\"\xee\x01\n\rAWSCredential\x12M\n\naccess_key\x18\x01 \x01(\x0b\x32,.kaskada.api.v1alpha.AWSCredential.AccessKeyH\x00R\taccessKey\x1a{\n\tAccessKey\x12\x32\n\x11\x61ws_access_key_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0e\x61wsAccessKeyId\x12:\n\x15\x61ws_secret_access_key\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x12\x61wsSecretAccessKeyB\x11\n\ncredential\x12\x03\xf8\x42\x01\"\xfc\x02\n\x0e\x45xternalS3File\x12;\n\x14virtual_hosted_style\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00R\x12virtualHostedStyle\x12\x61\n\x11\x62ucket_region_key\x18\x02 \x01(\x0b\x32\x33.kaskada.api.v1alpha.ExternalS3File.BucketRegionKeyH\x00R\x0f\x62ucketRegionKey\x12I\n\x0e\x61ws_credential\x18\x10 \x01(\x0b\x32\".kaskada.api.v1alpha.AWSCredentialR\rawsCredential\x1an\n\x0f\x42ucketRegionKey\x12\x1f\n\x06\x62ucket\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x62ucket\x12\x1f\n\x06region\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06region\x12\x19\n\x03key\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x03keyB\x0f\n\x08location\x12\x03\xf8\x42\x01\"/\n\x0eRequestDetails\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\"P\n\x0bResumeToken\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12\x1d\n\nquery_hash\x18\x02 \x01(\x0cR\tqueryHashBV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[kaskada_dot_errdetails_dot_v1alpha_dot_fenl__diagnostics__pb2.DESCRIPTOR,kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_ANALYSIS = _descriptor.Descriptor(
  name='Analysis',
  full_name='kaskada.api.v1alpha.Analysis',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='missing_names', full_name='kaskada.api.v1alpha.Analysis.missing_names', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='missingNames', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fenl_diagnostics', full_name='kaskada.api.v1alpha.Analysis.fenl_diagnostics', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fenlDiagnostics', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='can_execute', full_name='kaskada.api.v1alpha.Analysis.can_execute', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='canExecute', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=169,
  serialized_end=337,
)


_AWSCREDENTIAL_ACCESSKEY = _descriptor.Descriptor(
  name='AccessKey',
  full_name='kaskada.api.v1alpha.AWSCredential.AccessKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='aws_access_key_id', full_name='kaskada.api.v1alpha.AWSCredential.AccessKey.aws_access_key_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='awsAccessKeyId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aws_secret_access_key', full_name='kaskada.api.v1alpha.AWSCredential.AccessKey.aws_secret_access_key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='awsSecretAccessKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=436,
  serialized_end=559,
)

_AWSCREDENTIAL = _descriptor.Descriptor(
  name='AWSCredential',
  full_name='kaskada.api.v1alpha.AWSCredential',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_key', full_name='kaskada.api.v1alpha.AWSCredential.access_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='accessKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_AWSCREDENTIAL_ACCESSKEY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='credential', full_name='kaskada.api.v1alpha.AWSCredential.credential',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=340,
  serialized_end=578,
)


_EXTERNALS3FILE_BUCKETREGIONKEY = _descriptor.Descriptor(
  name='BucketRegionKey',
  full_name='kaskada.api.v1alpha.ExternalS3File.BucketRegionKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='kaskada.api.v1alpha.ExternalS3File.BucketRegionKey.bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='bucket', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region', full_name='kaskada.api.v1alpha.ExternalS3File.BucketRegionKey.region', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='region', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='kaskada.api.v1alpha.ExternalS3File.BucketRegionKey.key', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=834,
  serialized_end=944,
)

_EXTERNALS3FILE = _descriptor.Descriptor(
  name='ExternalS3File',
  full_name='kaskada.api.v1alpha.ExternalS3File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='virtual_hosted_style', full_name='kaskada.api.v1alpha.ExternalS3File.virtual_hosted_style', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='virtualHostedStyle', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='bucket_region_key', full_name='kaskada.api.v1alpha.ExternalS3File.bucket_region_key', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='bucketRegionKey', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='aws_credential', full_name='kaskada.api.v1alpha.ExternalS3File.aws_credential', index=2,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='awsCredential', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXTERNALS3FILE_BUCKETREGIONKEY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='location', full_name='kaskada.api.v1alpha.ExternalS3File.location',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=581,
  serialized_end=961,
)


_REQUESTDETAILS = _descriptor.Descriptor(
  name='RequestDetails',
  full_name='kaskada.api.v1alpha.RequestDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_id', full_name='kaskada.api.v1alpha.RequestDetails.request_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=963,
  serialized_end=1010,
)


_RESUMETOKEN = _descriptor.Descriptor(
  name='ResumeToken',
  full_name='kaskada.api.v1alpha.ResumeToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.ResumeToken.data_token_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_hash', full_name='kaskada.api.v1alpha.ResumeToken.query_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='queryHash', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1012,
  serialized_end=1092,
)

_ANALYSIS.fields_by_name['fenl_diagnostics'].message_type = kaskada_dot_errdetails_dot_v1alpha_dot_fenl__diagnostics__pb2._FENLDIAGNOSTICS
_AWSCREDENTIAL_ACCESSKEY.containing_type = _AWSCREDENTIAL
_AWSCREDENTIAL.fields_by_name['access_key'].message_type = _AWSCREDENTIAL_ACCESSKEY
_AWSCREDENTIAL.oneofs_by_name['credential'].fields.append(
  _AWSCREDENTIAL.fields_by_name['access_key'])
_AWSCREDENTIAL.fields_by_name['access_key'].containing_oneof = _AWSCREDENTIAL.oneofs_by_name['credential']
_EXTERNALS3FILE_BUCKETREGIONKEY.containing_type = _EXTERNALS3FILE
_EXTERNALS3FILE.fields_by_name['bucket_region_key'].message_type = _EXTERNALS3FILE_BUCKETREGIONKEY
_EXTERNALS3FILE.fields_by_name['aws_credential'].message_type = _AWSCREDENTIAL
_EXTERNALS3FILE.oneofs_by_name['location'].fields.append(
  _EXTERNALS3FILE.fields_by_name['virtual_hosted_style'])
_EXTERNALS3FILE.fields_by_name['virtual_hosted_style'].containing_oneof = _EXTERNALS3FILE.oneofs_by_name['location']
_EXTERNALS3FILE.oneofs_by_name['location'].fields.append(
  _EXTERNALS3FILE.fields_by_name['bucket_region_key'])
_EXTERNALS3FILE.fields_by_name['bucket_region_key'].containing_oneof = _EXTERNALS3FILE.oneofs_by_name['location']
DESCRIPTOR.message_types_by_name['Analysis'] = _ANALYSIS
DESCRIPTOR.message_types_by_name['AWSCredential'] = _AWSCREDENTIAL
DESCRIPTOR.message_types_by_name['ExternalS3File'] = _EXTERNALS3FILE
DESCRIPTOR.message_types_by_name['RequestDetails'] = _REQUESTDETAILS
DESCRIPTOR.message_types_by_name['ResumeToken'] = _RESUMETOKEN
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Analysis = _reflection.GeneratedProtocolMessageType('Analysis', (_message.Message,), {
  'DESCRIPTOR' : _ANALYSIS,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Analysis)
  })
_sym_db.RegisterMessage(Analysis)

AWSCredential = _reflection.GeneratedProtocolMessageType('AWSCredential', (_message.Message,), {

  'AccessKey' : _reflection.GeneratedProtocolMessageType('AccessKey', (_message.Message,), {
    'DESCRIPTOR' : _AWSCREDENTIAL_ACCESSKEY,
    '__module__' : 'kaskada.api.v1alpha.shared_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.AWSCredential.AccessKey)
    })
  ,
  'DESCRIPTOR' : _AWSCREDENTIAL,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.AWSCredential)
  })
_sym_db.RegisterMessage(AWSCredential)
_sym_db.RegisterMessage(AWSCredential.AccessKey)

ExternalS3File = _reflection.GeneratedProtocolMessageType('ExternalS3File', (_message.Message,), {

  'BucketRegionKey' : _reflection.GeneratedProtocolMessageType('BucketRegionKey', (_message.Message,), {
    'DESCRIPTOR' : _EXTERNALS3FILE_BUCKETREGIONKEY,
    '__module__' : 'kaskada.api.v1alpha.shared_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ExternalS3File.BucketRegionKey)
    })
  ,
  'DESCRIPTOR' : _EXTERNALS3FILE,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ExternalS3File)
  })
_sym_db.RegisterMessage(ExternalS3File)
_sym_db.RegisterMessage(ExternalS3File.BucketRegionKey)

RequestDetails = _reflection.GeneratedProtocolMessageType('RequestDetails', (_message.Message,), {
  'DESCRIPTOR' : _REQUESTDETAILS,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.RequestDetails)
  })
_sym_db.RegisterMessage(RequestDetails)

ResumeToken = _reflection.GeneratedProtocolMessageType('ResumeToken', (_message.Message,), {
  'DESCRIPTOR' : _RESUMETOKEN,
  '__module__' : 'kaskada.api.v1alpha.shared_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ResumeToken)
  })
_sym_db.RegisterMessage(ResumeToken)


DESCRIPTOR._options = None
_AWSCREDENTIAL_ACCESSKEY.fields_by_name['aws_access_key_id']._options = None
_AWSCREDENTIAL_ACCESSKEY.fields_by_name['aws_secret_access_key']._options = None
_AWSCREDENTIAL.oneofs_by_name['credential']._options = None
_EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['bucket']._options = None
_EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['region']._options = None
_EXTERNALS3FILE_BUCKETREGIONKEY.fields_by_name['key']._options = None
_EXTERNALS3FILE.oneofs_by_name['location']._options = None
_EXTERNALS3FILE.fields_by_name['virtual_hosted_style']._options = None
# @@protoc_insertion_point(module_scope)
