# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/data_token.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/data_token.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n$kaskada/api/v1alpha/data_token.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a kaskada/api/v1alpha/shared.proto\"\xd7\x01\n\tDataToken\x12(\n\rdata_token_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x0b\x64\x61taTokenId\x12^\n\x0etable_versions\x18\x02 \x03(\x0b\x32\x31.kaskada.api.v1alpha.DataToken.TableVersionsEntryB\x04\xe2\x41\x01\x03R\rtableVersions\x1a@\n\x12TableVersionsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\"9\n\x13GetDataTokenRequest\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\"\xa3\x01\n\x14GetDataTokenResponse\x12=\n\ndata_token\x18\x01 \x01(\x0b\x32\x1e.kaskada.api.v1alpha.DataTokenR\tdataToken\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\xa8\x01\n\x10\x44\x61taTokenService\x12\x93\x01\n\x0cGetDataToken\x12(.kaskada.api.v1alpha.GetDataTokenRequest\x1a).kaskada.api.v1alpha.GetDataTokenResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1alpha/data_tokens/{data_token_id=*}BV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,])




_DATATOKEN_TABLEVERSIONSENTRY = _descriptor.Descriptor(
  name='TableVersionsEntry',
  full_name='kaskada.api.v1alpha.DataToken.TableVersionsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='kaskada.api.v1alpha.DataToken.TableVersionsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='kaskada.api.v1alpha.DataToken.TableVersionsEntry.value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='value', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=310,
  serialized_end=374,
)

_DATATOKEN = _descriptor.Descriptor(
  name='DataToken',
  full_name='kaskada.api.v1alpha.DataToken',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.DataToken.data_token_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_versions', full_name='kaskada.api.v1alpha.DataToken.table_versions', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='tableVersions', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_DATATOKEN_TABLEVERSIONSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=159,
  serialized_end=374,
)


_GETDATATOKENREQUEST = _descriptor.Descriptor(
  name='GetDataTokenRequest',
  full_name='kaskada.api.v1alpha.GetDataTokenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.GetDataTokenRequest.data_token_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=376,
  serialized_end=433,
)


_GETDATATOKENRESPONSE = _descriptor.Descriptor(
  name='GetDataTokenResponse',
  full_name='kaskada.api.v1alpha.GetDataTokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_token', full_name='kaskada.api.v1alpha.GetDataTokenResponse.data_token', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.GetDataTokenResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=436,
  serialized_end=599,
)

_DATATOKEN_TABLEVERSIONSENTRY.containing_type = _DATATOKEN
_DATATOKEN.fields_by_name['table_versions'].message_type = _DATATOKEN_TABLEVERSIONSENTRY
_GETDATATOKENRESPONSE.fields_by_name['data_token'].message_type = _DATATOKEN
_GETDATATOKENRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
DESCRIPTOR.message_types_by_name['DataToken'] = _DATATOKEN
DESCRIPTOR.message_types_by_name['GetDataTokenRequest'] = _GETDATATOKENREQUEST
DESCRIPTOR.message_types_by_name['GetDataTokenResponse'] = _GETDATATOKENRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataToken = _reflection.GeneratedProtocolMessageType('DataToken', (_message.Message,), {

  'TableVersionsEntry' : _reflection.GeneratedProtocolMessageType('TableVersionsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATATOKEN_TABLEVERSIONSENTRY,
    '__module__' : 'kaskada.api.v1alpha.data_token_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DataToken.TableVersionsEntry)
    })
  ,
  'DESCRIPTOR' : _DATATOKEN,
  '__module__' : 'kaskada.api.v1alpha.data_token_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DataToken)
  })
_sym_db.RegisterMessage(DataToken)
_sym_db.RegisterMessage(DataToken.TableVersionsEntry)

GetDataTokenRequest = _reflection.GeneratedProtocolMessageType('GetDataTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATATOKENREQUEST,
  '__module__' : 'kaskada.api.v1alpha.data_token_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetDataTokenRequest)
  })
_sym_db.RegisterMessage(GetDataTokenRequest)

GetDataTokenResponse = _reflection.GeneratedProtocolMessageType('GetDataTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATATOKENRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.data_token_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetDataTokenResponse)
  })
_sym_db.RegisterMessage(GetDataTokenResponse)


DESCRIPTOR._options = None
_DATATOKEN_TABLEVERSIONSENTRY._options = None
_DATATOKEN.fields_by_name['data_token_id']._options = None
_DATATOKEN.fields_by_name['table_versions']._options = None

_DATATOKENSERVICE = _descriptor.ServiceDescriptor(
  name='DataTokenService',
  full_name='kaskada.api.v1alpha.DataTokenService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=602,
  serialized_end=770,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetDataToken',
    full_name='kaskada.api.v1alpha.DataTokenService.GetDataToken',
    index=0,
    containing_service=None,
    input_type=_GETDATATOKENREQUEST,
    output_type=_GETDATATOKENRESPONSE,
    serialized_options=b'\202\323\344\223\002(\022&/v1alpha/data_tokens/{data_token_id=*}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_DATATOKENSERVICE)

DESCRIPTOR.services_by_name['DataTokenService'] = _DATATOKENSERVICE

# @@protoc_insertion_point(module_scope)
