# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/compute.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from kaskada.prepare.v1alpha import slice_pb2 as kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/compute.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!kaskada/api/v1alpha/compute.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a kaskada/api/v1alpha/shared.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a#kaskada/prepare/v1alpha/slice.proto\x1a\x17validate/validate.proto\"\xab\x02\n\tWithTable\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x16\n\x06\x65ntity\x18\x02 \x01(\tR\x06\x65ntity\x12\x12\n\x04time\x18\x03 \x01(\tR\x04time\x12%\n\rparquet_bytes\x18\x04 \x01(\x0cH\x00R\x0cparquetBytes\x12#\n\x0cparquet_path\x18\x05 \x01(\tH\x00R\x0bparquetPath\x12L\n\x0bjson_values\x18\x06 \x01(\x0b\x32).kaskada.api.v1alpha.WithTable.JSONValuesH\x00R\njsonValues\x1a<\n\nJSONValues\x12\x16\n\x06schema\x18\x01 \x01(\tR\x06schema\x12\x16\n\x06values\x18\x02 \x03(\tR\x06valuesB\x06\n\x04\x64\x61ta\">\n\x08WithView\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1e\n\nexpression\x18\x02 \x01(\tR\nexpression\">\n\x0e\x41nalyzeRequest\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x12\x16\n\x06isView\x18\x02 \x01(\x08R\x06isView\"\xdb\x01\n\x0f\x41nalyzeResponse\x12?\n\x0bresult_type\x18\x01 \x01(\x0b\x32\x1e.kaskada.fenl.v1alpha.DataTypeR\nresultType\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\x12\x39\n\x08\x61nalysis\x18\x03 \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisR\x08\x61nalysis\"\xd8\x08\n\x0cQueryRequest\x12\x14\n\x05query\x18\x01 \x01(\tR\x05query\x12?\n\x0bwith_tables\x18\x02 \x03(\x0b\x32\x1e.kaskada.api.v1alpha.WithTableR\nwithTables\x12<\n\nwith_views\x18\x03 \x03(\x0b\x32\x1d.kaskada.api.v1alpha.WithViewR\twithViews\x12J\n\x0bjson_values\x18\x04 \x01(\x0b\x32\'.kaskada.api.v1alpha.QueryRequest.EmptyH\x00R\njsonValues\x12\x43\n\x07parquet\x18\x05 \x01(\x0b\x32\'.kaskada.api.v1alpha.QueryRequest.EmptyH\x00R\x07parquet\x12T\n\nredis_bulk\x18\x06 \x01(\x0b\x32\x33.kaskada.api.v1alpha.QueryRequest.RedisBulkResponseH\x00R\tredisBulk\x12G\n\tredis_a_i\x18\x08 \x01(\x0b\x32).kaskada.api.v1alpha.QueryRequest.RedisAIH\x00R\x07redisAI\x12\"\n\rdata_token_id\x18\x07 \x01(\tR\x0b\x64\x61taTokenId\x12Y\n\x0fresult_behavior\x18\t \x01(\x0e\x32\x30.kaskada.api.v1alpha.QueryRequest.ResultBehaviorR\x0eresultBehavior\x12@\n\x06limits\x18\n \x01(\x0b\x32(.kaskada.api.v1alpha.QueryRequest.LimitsR\x06limits\x12!\n\x0cresume_token\x18\x0b \x01(\tR\x0bresumeToken\x12;\n\x05slice\x18\x0c \x01(\x0b\x32%.kaskada.prepare.v1alpha.SliceRequestR\x05slice\x12\x17\n\x07\x64ry_run\x18\r \x01(\x08R\x06\x64ryRun\x1a\x07\n\x05\x45mpty\x1a+\n\x06Limits\x12!\n\x0cpreview_rows\x18\x01 \x01(\x03R\x0bpreviewRows\x1a)\n\x11RedisBulkResponse\x12\x14\n\x05shape\x18\x01 \x03(\x05R\x05shape\x1a\x62\n\x07RedisAI\x12\x19\n\x02\x64\x62\x18\x01 \x01(\x05\x42\t\xfa\x42\x06\x1a\x04\x18\x0f(\x00R\x02\x64\x62\x12\x1b\n\x04host\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x04host\x12\x1f\n\x04port\x18\x03 \x01(\x05\x42\x0b\xfa\x42\x08\x1a\x06\x18\xff\xff\x03 \x00R\x04port\"u\n\x0eResultBehavior\x12\x1f\n\x1bRESULT_BEHAVIOR_UNSPECIFIED\x10\x00\x12\x1f\n\x1bRESULT_BEHAVIOR_ALL_RESULTS\x10\x01\x12!\n\x1dRESULT_BEHAVIOR_FINAL_RESULTS\x10\x02\x42\r\n\x0bresponse_as\"\x8c\x06\n\rQueryResponse\x12P\n\x0bjson_values\x18\x02 \x01(\x0b\x32-.kaskada.api.v1alpha.QueryResponse.JSONValuesH\x00R\njsonValues\x12\x46\n\x07parquet\x18\x03 \x01(\x0b\x32*.kaskada.api.v1alpha.QueryResponse.ParquetH\x00R\x07parquet\x12M\n\nredis_bulk\x18\x04 \x01(\x0b\x32,.kaskada.api.v1alpha.QueryResponse.RedisBulkH\x00R\tredisBulk\x12H\n\tredis_a_i\x18\x06 \x01(\x0b\x32*.kaskada.api.v1alpha.QueryResponse.RedisAIH\x00R\x07redisAI\x12\"\n\rdata_token_id\x18\x05 \x01(\tR\x0b\x64\x61taTokenId\x12L\n\x0frequest_details\x18\x07 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\x12*\n\x11next_resume_token\x18\x08 \x01(\tR\x0fnextResumeToken\x12\x39\n\x08\x61nalysis\x18\t \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisR\x08\x61nalysis\x12\x34\n\x06schema\x18\n \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaR\x06schema\x12;\n\x05slice\x18\x0b \x01(\x0b\x32%.kaskada.prepare.v1alpha.SliceRequestR\x05slice\x1a&\n\nJSONValues\x12\x18\n\x07results\x18\x01 \x03(\tR\x07results\x1a\x1d\n\x07Parquet\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x1a\x1f\n\tRedisBulk\x12\x12\n\x04path\x18\x01 \x01(\tR\x04path\x1a\t\n\x07RedisAIB\t\n\x07results2\xfe\x01\n\x0e\x43omputeService\x12y\n\x07\x41nalyze\x12#.kaskada.api.v1alpha.AnalyzeRequest\x1a$.kaskada.api.v1alpha.AnalyzeResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x18/v1alpha/compute/analyze:\x01*\x12q\n\x05Query\x12!.kaskada.api.v1alpha.QueryRequest\x1a\".kaskada.api.v1alpha.QueryResponse\"!\x82\xd3\xe4\x93\x02\x1b\"\x16/v1alpha/compute/query:\x01*BV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2.DESCRIPTOR,kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])



_QUERYREQUEST_RESULTBEHAVIOR = _descriptor.EnumDescriptor(
  name='ResultBehavior',
  full_name='kaskada.api.v1alpha.QueryRequest.ResultBehavior',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RESULT_BEHAVIOR_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESULT_BEHAVIOR_ALL_RESULTS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RESULT_BEHAVIOR_FINAL_RESULTS', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1852,
  serialized_end=1969,
)
_sym_db.RegisterEnumDescriptor(_QUERYREQUEST_RESULTBEHAVIOR)


_WITHTABLE_JSONVALUES = _descriptor.Descriptor(
  name='JSONValues',
  full_name='kaskada.api.v1alpha.WithTable.JSONValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='schema', full_name='kaskada.api.v1alpha.WithTable.JSONValues.schema', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='kaskada.api.v1alpha.WithTable.JSONValues.values', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='values', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=451,
  serialized_end=511,
)

_WITHTABLE = _descriptor.Descriptor(
  name='WithTable',
  full_name='kaskada.api.v1alpha.WithTable',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='kaskada.api.v1alpha.WithTable.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entity', full_name='kaskada.api.v1alpha.WithTable.entity', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='entity', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='kaskada.api.v1alpha.WithTable.time', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='time', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parquet_bytes', full_name='kaskada.api.v1alpha.WithTable.parquet_bytes', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parquetBytes', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parquet_path', full_name='kaskada.api.v1alpha.WithTable.parquet_path', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parquetPath', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json_values', full_name='kaskada.api.v1alpha.WithTable.json_values', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jsonValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_WITHTABLE_JSONVALUES, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='kaskada.api.v1alpha.WithTable.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=220,
  serialized_end=519,
)


_WITHVIEW = _descriptor.Descriptor(
  name='WithView',
  full_name='kaskada.api.v1alpha.WithView',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='kaskada.api.v1alpha.WithView.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expression', full_name='kaskada.api.v1alpha.WithView.expression', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='expression', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=521,
  serialized_end=583,
)


_ANALYZEREQUEST = _descriptor.Descriptor(
  name='AnalyzeRequest',
  full_name='kaskada.api.v1alpha.AnalyzeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='kaskada.api.v1alpha.AnalyzeRequest.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='isView', full_name='kaskada.api.v1alpha.AnalyzeRequest.isView', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='isView', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=585,
  serialized_end=647,
)


_ANALYZERESPONSE = _descriptor.Descriptor(
  name='AnalyzeResponse',
  full_name='kaskada.api.v1alpha.AnalyzeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result_type', full_name='kaskada.api.v1alpha.AnalyzeResponse.result_type', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resultType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.AnalyzeResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analysis', full_name='kaskada.api.v1alpha.AnalyzeResponse.analysis', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='analysis', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=650,
  serialized_end=869,
)


_QUERYREQUEST_EMPTY = _descriptor.Descriptor(
  name='Empty',
  full_name='kaskada.api.v1alpha.QueryRequest.Empty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1655,
  serialized_end=1662,
)

_QUERYREQUEST_LIMITS = _descriptor.Descriptor(
  name='Limits',
  full_name='kaskada.api.v1alpha.QueryRequest.Limits',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='preview_rows', full_name='kaskada.api.v1alpha.QueryRequest.Limits.preview_rows', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='previewRows', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1664,
  serialized_end=1707,
)

_QUERYREQUEST_REDISBULKRESPONSE = _descriptor.Descriptor(
  name='RedisBulkResponse',
  full_name='kaskada.api.v1alpha.QueryRequest.RedisBulkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='shape', full_name='kaskada.api.v1alpha.QueryRequest.RedisBulkResponse.shape', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='shape', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1709,
  serialized_end=1750,
)

_QUERYREQUEST_REDISAI = _descriptor.Descriptor(
  name='RedisAI',
  full_name='kaskada.api.v1alpha.QueryRequest.RedisAI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='db', full_name='kaskada.api.v1alpha.QueryRequest.RedisAI.db', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\006\032\004\030\017(\000', json_name='db', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host', full_name='kaskada.api.v1alpha.QueryRequest.RedisAI.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='host', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='kaskada.api.v1alpha.QueryRequest.RedisAI.port', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010\032\006\030\377\377\003 \000', json_name='port', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1752,
  serialized_end=1850,
)

_QUERYREQUEST = _descriptor.Descriptor(
  name='QueryRequest',
  full_name='kaskada.api.v1alpha.QueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='query', full_name='kaskada.api.v1alpha.QueryRequest.query', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='query', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_tables', full_name='kaskada.api.v1alpha.QueryRequest.with_tables', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='withTables', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='with_views', full_name='kaskada.api.v1alpha.QueryRequest.with_views', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='withViews', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='json_values', full_name='kaskada.api.v1alpha.QueryRequest.json_values', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jsonValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parquet', full_name='kaskada.api.v1alpha.QueryRequest.parquet', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parquet', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redis_bulk', full_name='kaskada.api.v1alpha.QueryRequest.redis_bulk', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redisBulk', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redis_a_i', full_name='kaskada.api.v1alpha.QueryRequest.redis_a_i', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redisAI', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.QueryRequest.data_token_id', index=7,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_behavior', full_name='kaskada.api.v1alpha.QueryRequest.result_behavior', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resultBehavior', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='limits', full_name='kaskada.api.v1alpha.QueryRequest.limits', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='limits', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='resume_token', full_name='kaskada.api.v1alpha.QueryRequest.resume_token', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='resumeToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slice', full_name='kaskada.api.v1alpha.QueryRequest.slice', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slice', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='dry_run', full_name='kaskada.api.v1alpha.QueryRequest.dry_run', index=12,
      number=13, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dryRun', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUERYREQUEST_EMPTY, _QUERYREQUEST_LIMITS, _QUERYREQUEST_REDISBULKRESPONSE, _QUERYREQUEST_REDISAI, ],
  enum_types=[
    _QUERYREQUEST_RESULTBEHAVIOR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='response_as', full_name='kaskada.api.v1alpha.QueryRequest.response_as',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=872,
  serialized_end=1984,
)


_QUERYRESPONSE_JSONVALUES = _descriptor.Descriptor(
  name='JSONValues',
  full_name='kaskada.api.v1alpha.QueryResponse.JSONValues',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='kaskada.api.v1alpha.QueryResponse.JSONValues.results', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='results', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2643,
  serialized_end=2681,
)

_QUERYRESPONSE_PARQUET = _descriptor.Descriptor(
  name='Parquet',
  full_name='kaskada.api.v1alpha.QueryResponse.Parquet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='kaskada.api.v1alpha.QueryResponse.Parquet.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='path', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2683,
  serialized_end=2712,
)

_QUERYRESPONSE_REDISBULK = _descriptor.Descriptor(
  name='RedisBulk',
  full_name='kaskada.api.v1alpha.QueryResponse.RedisBulk',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='kaskada.api.v1alpha.QueryResponse.RedisBulk.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='path', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2714,
  serialized_end=2745,
)

_QUERYRESPONSE_REDISAI = _descriptor.Descriptor(
  name='RedisAI',
  full_name='kaskada.api.v1alpha.QueryResponse.RedisAI',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1752,
  serialized_end=1761,
)

_QUERYRESPONSE = _descriptor.Descriptor(
  name='QueryResponse',
  full_name='kaskada.api.v1alpha.QueryResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='json_values', full_name='kaskada.api.v1alpha.QueryResponse.json_values', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='jsonValues', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parquet', full_name='kaskada.api.v1alpha.QueryResponse.parquet', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='parquet', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redis_bulk', full_name='kaskada.api.v1alpha.QueryResponse.redis_bulk', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redisBulk', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='redis_a_i', full_name='kaskada.api.v1alpha.QueryResponse.redis_a_i', index=3,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='redisAI', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.QueryResponse.data_token_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.QueryResponse.request_details', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_resume_token', full_name='kaskada.api.v1alpha.QueryResponse.next_resume_token', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nextResumeToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analysis', full_name='kaskada.api.v1alpha.QueryResponse.analysis', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='analysis', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='kaskada.api.v1alpha.QueryResponse.schema', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='slice', full_name='kaskada.api.v1alpha.QueryResponse.slice', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='slice', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_QUERYRESPONSE_JSONVALUES, _QUERYRESPONSE_PARQUET, _QUERYRESPONSE_REDISBULK, _QUERYRESPONSE_REDISAI, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='results', full_name='kaskada.api.v1alpha.QueryResponse.results',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1987,
  serialized_end=2767,
)

_WITHTABLE_JSONVALUES.containing_type = _WITHTABLE
_WITHTABLE.fields_by_name['json_values'].message_type = _WITHTABLE_JSONVALUES
_WITHTABLE.oneofs_by_name['data'].fields.append(
  _WITHTABLE.fields_by_name['parquet_bytes'])
_WITHTABLE.fields_by_name['parquet_bytes'].containing_oneof = _WITHTABLE.oneofs_by_name['data']
_WITHTABLE.oneofs_by_name['data'].fields.append(
  _WITHTABLE.fields_by_name['parquet_path'])
_WITHTABLE.fields_by_name['parquet_path'].containing_oneof = _WITHTABLE.oneofs_by_name['data']
_WITHTABLE.oneofs_by_name['data'].fields.append(
  _WITHTABLE.fields_by_name['json_values'])
_WITHTABLE.fields_by_name['json_values'].containing_oneof = _WITHTABLE.oneofs_by_name['data']
_ANALYZERESPONSE.fields_by_name['result_type'].message_type = kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2._DATATYPE
_ANALYZERESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_ANALYZERESPONSE.fields_by_name['analysis'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._ANALYSIS
_QUERYREQUEST_EMPTY.containing_type = _QUERYREQUEST
_QUERYREQUEST_LIMITS.containing_type = _QUERYREQUEST
_QUERYREQUEST_REDISBULKRESPONSE.containing_type = _QUERYREQUEST
_QUERYREQUEST_REDISAI.containing_type = _QUERYREQUEST
_QUERYREQUEST.fields_by_name['with_tables'].message_type = _WITHTABLE
_QUERYREQUEST.fields_by_name['with_views'].message_type = _WITHVIEW
_QUERYREQUEST.fields_by_name['json_values'].message_type = _QUERYREQUEST_EMPTY
_QUERYREQUEST.fields_by_name['parquet'].message_type = _QUERYREQUEST_EMPTY
_QUERYREQUEST.fields_by_name['redis_bulk'].message_type = _QUERYREQUEST_REDISBULKRESPONSE
_QUERYREQUEST.fields_by_name['redis_a_i'].message_type = _QUERYREQUEST_REDISAI
_QUERYREQUEST.fields_by_name['result_behavior'].enum_type = _QUERYREQUEST_RESULTBEHAVIOR
_QUERYREQUEST.fields_by_name['limits'].message_type = _QUERYREQUEST_LIMITS
_QUERYREQUEST.fields_by_name['slice'].message_type = kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2._SLICEREQUEST
_QUERYREQUEST_RESULTBEHAVIOR.containing_type = _QUERYREQUEST
_QUERYREQUEST.oneofs_by_name['response_as'].fields.append(
  _QUERYREQUEST.fields_by_name['json_values'])
_QUERYREQUEST.fields_by_name['json_values'].containing_oneof = _QUERYREQUEST.oneofs_by_name['response_as']
_QUERYREQUEST.oneofs_by_name['response_as'].fields.append(
  _QUERYREQUEST.fields_by_name['parquet'])
_QUERYREQUEST.fields_by_name['parquet'].containing_oneof = _QUERYREQUEST.oneofs_by_name['response_as']
_QUERYREQUEST.oneofs_by_name['response_as'].fields.append(
  _QUERYREQUEST.fields_by_name['redis_bulk'])
_QUERYREQUEST.fields_by_name['redis_bulk'].containing_oneof = _QUERYREQUEST.oneofs_by_name['response_as']
_QUERYREQUEST.oneofs_by_name['response_as'].fields.append(
  _QUERYREQUEST.fields_by_name['redis_a_i'])
_QUERYREQUEST.fields_by_name['redis_a_i'].containing_oneof = _QUERYREQUEST.oneofs_by_name['response_as']
_QUERYRESPONSE_JSONVALUES.containing_type = _QUERYRESPONSE
_QUERYRESPONSE_PARQUET.containing_type = _QUERYRESPONSE
_QUERYRESPONSE_REDISBULK.containing_type = _QUERYRESPONSE
_QUERYRESPONSE_REDISAI.containing_type = _QUERYRESPONSE
_QUERYRESPONSE.fields_by_name['json_values'].message_type = _QUERYRESPONSE_JSONVALUES
_QUERYRESPONSE.fields_by_name['parquet'].message_type = _QUERYRESPONSE_PARQUET
_QUERYRESPONSE.fields_by_name['redis_bulk'].message_type = _QUERYRESPONSE_REDISBULK
_QUERYRESPONSE.fields_by_name['redis_a_i'].message_type = _QUERYRESPONSE_REDISAI
_QUERYRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_QUERYRESPONSE.fields_by_name['analysis'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._ANALYSIS
_QUERYRESPONSE.fields_by_name['schema'].message_type = kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2._SCHEMA
_QUERYRESPONSE.fields_by_name['slice'].message_type = kaskada_dot_prepare_dot_v1alpha_dot_slice__pb2._SLICEREQUEST
_QUERYRESPONSE.oneofs_by_name['results'].fields.append(
  _QUERYRESPONSE.fields_by_name['json_values'])
_QUERYRESPONSE.fields_by_name['json_values'].containing_oneof = _QUERYRESPONSE.oneofs_by_name['results']
_QUERYRESPONSE.oneofs_by_name['results'].fields.append(
  _QUERYRESPONSE.fields_by_name['parquet'])
_QUERYRESPONSE.fields_by_name['parquet'].containing_oneof = _QUERYRESPONSE.oneofs_by_name['results']
_QUERYRESPONSE.oneofs_by_name['results'].fields.append(
  _QUERYRESPONSE.fields_by_name['redis_bulk'])
_QUERYRESPONSE.fields_by_name['redis_bulk'].containing_oneof = _QUERYRESPONSE.oneofs_by_name['results']
_QUERYRESPONSE.oneofs_by_name['results'].fields.append(
  _QUERYRESPONSE.fields_by_name['redis_a_i'])
_QUERYRESPONSE.fields_by_name['redis_a_i'].containing_oneof = _QUERYRESPONSE.oneofs_by_name['results']
DESCRIPTOR.message_types_by_name['WithTable'] = _WITHTABLE
DESCRIPTOR.message_types_by_name['WithView'] = _WITHVIEW
DESCRIPTOR.message_types_by_name['AnalyzeRequest'] = _ANALYZEREQUEST
DESCRIPTOR.message_types_by_name['AnalyzeResponse'] = _ANALYZERESPONSE
DESCRIPTOR.message_types_by_name['QueryRequest'] = _QUERYREQUEST
DESCRIPTOR.message_types_by_name['QueryResponse'] = _QUERYRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

WithTable = _reflection.GeneratedProtocolMessageType('WithTable', (_message.Message,), {

  'JSONValues' : _reflection.GeneratedProtocolMessageType('JSONValues', (_message.Message,), {
    'DESCRIPTOR' : _WITHTABLE_JSONVALUES,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.WithTable.JSONValues)
    })
  ,
  'DESCRIPTOR' : _WITHTABLE,
  '__module__' : 'kaskada.api.v1alpha.compute_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.WithTable)
  })
_sym_db.RegisterMessage(WithTable)
_sym_db.RegisterMessage(WithTable.JSONValues)

WithView = _reflection.GeneratedProtocolMessageType('WithView', (_message.Message,), {
  'DESCRIPTOR' : _WITHVIEW,
  '__module__' : 'kaskada.api.v1alpha.compute_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.WithView)
  })
_sym_db.RegisterMessage(WithView)

AnalyzeRequest = _reflection.GeneratedProtocolMessageType('AnalyzeRequest', (_message.Message,), {
  'DESCRIPTOR' : _ANALYZEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.compute_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.AnalyzeRequest)
  })
_sym_db.RegisterMessage(AnalyzeRequest)

AnalyzeResponse = _reflection.GeneratedProtocolMessageType('AnalyzeResponse', (_message.Message,), {
  'DESCRIPTOR' : _ANALYZERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.compute_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.AnalyzeResponse)
  })
_sym_db.RegisterMessage(AnalyzeResponse)

QueryRequest = _reflection.GeneratedProtocolMessageType('QueryRequest', (_message.Message,), {

  'Empty' : _reflection.GeneratedProtocolMessageType('Empty', (_message.Message,), {
    'DESCRIPTOR' : _QUERYREQUEST_EMPTY,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryRequest.Empty)
    })
  ,

  'Limits' : _reflection.GeneratedProtocolMessageType('Limits', (_message.Message,), {
    'DESCRIPTOR' : _QUERYREQUEST_LIMITS,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryRequest.Limits)
    })
  ,

  'RedisBulkResponse' : _reflection.GeneratedProtocolMessageType('RedisBulkResponse', (_message.Message,), {
    'DESCRIPTOR' : _QUERYREQUEST_REDISBULKRESPONSE,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryRequest.RedisBulkResponse)
    })
  ,

  'RedisAI' : _reflection.GeneratedProtocolMessageType('RedisAI', (_message.Message,), {
    'DESCRIPTOR' : _QUERYREQUEST_REDISAI,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryRequest.RedisAI)
    })
  ,
  'DESCRIPTOR' : _QUERYREQUEST,
  '__module__' : 'kaskada.api.v1alpha.compute_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryRequest)
  })
_sym_db.RegisterMessage(QueryRequest)
_sym_db.RegisterMessage(QueryRequest.Empty)
_sym_db.RegisterMessage(QueryRequest.Limits)
_sym_db.RegisterMessage(QueryRequest.RedisBulkResponse)
_sym_db.RegisterMessage(QueryRequest.RedisAI)

QueryResponse = _reflection.GeneratedProtocolMessageType('QueryResponse', (_message.Message,), {

  'JSONValues' : _reflection.GeneratedProtocolMessageType('JSONValues', (_message.Message,), {
    'DESCRIPTOR' : _QUERYRESPONSE_JSONVALUES,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryResponse.JSONValues)
    })
  ,

  'Parquet' : _reflection.GeneratedProtocolMessageType('Parquet', (_message.Message,), {
    'DESCRIPTOR' : _QUERYRESPONSE_PARQUET,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryResponse.Parquet)
    })
  ,

  'RedisBulk' : _reflection.GeneratedProtocolMessageType('RedisBulk', (_message.Message,), {
    'DESCRIPTOR' : _QUERYRESPONSE_REDISBULK,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryResponse.RedisBulk)
    })
  ,

  'RedisAI' : _reflection.GeneratedProtocolMessageType('RedisAI', (_message.Message,), {
    'DESCRIPTOR' : _QUERYRESPONSE_REDISAI,
    '__module__' : 'kaskada.api.v1alpha.compute_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryResponse.RedisAI)
    })
  ,
  'DESCRIPTOR' : _QUERYRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.compute_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.QueryResponse)
  })
_sym_db.RegisterMessage(QueryResponse)
_sym_db.RegisterMessage(QueryResponse.JSONValues)
_sym_db.RegisterMessage(QueryResponse.Parquet)
_sym_db.RegisterMessage(QueryResponse.RedisBulk)
_sym_db.RegisterMessage(QueryResponse.RedisAI)


DESCRIPTOR._options = None
_QUERYREQUEST_REDISAI.fields_by_name['db']._options = None
_QUERYREQUEST_REDISAI.fields_by_name['host']._options = None
_QUERYREQUEST_REDISAI.fields_by_name['port']._options = None

_COMPUTESERVICE = _descriptor.ServiceDescriptor(
  name='ComputeService',
  full_name='kaskada.api.v1alpha.ComputeService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2770,
  serialized_end=3024,
  methods=[
  _descriptor.MethodDescriptor(
    name='Analyze',
    full_name='kaskada.api.v1alpha.ComputeService.Analyze',
    index=0,
    containing_service=None,
    input_type=_ANALYZEREQUEST,
    output_type=_ANALYZERESPONSE,
    serialized_options=b'\202\323\344\223\002\035\"\030/v1alpha/compute/analyze:\001*',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Query',
    full_name='kaskada.api.v1alpha.ComputeService.Query',
    index=1,
    containing_service=None,
    input_type=_QUERYREQUEST,
    output_type=_QUERYRESPONSE,
    serialized_options=b'\202\323\344\223\002\033\"\026/v1alpha/compute/query:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_COMPUTESERVICE)

DESCRIPTOR.services_by_name['ComputeService'] = _COMPUTESERVICE

# @@protoc_insertion_point(module_scope)
