# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/errdetails/v1alpha/fenl_diagnostics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/errdetails/v1alpha/fenl_diagnostics.proto',
  package='kaskada.errdetails.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\036com.kaskada.errdetails.v1alphaP\001ZAgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/errdetails/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n1kaskada/errdetails/v1alpha/fenl_diagnostics.proto\x12\x1akaskada.errdetails.v1alpha\"\x87\x01\n\x0f\x46\x65nlDiagnostics\x12U\n\x10\x66\x65nl_diagnostics\x18\x01 \x03(\x0b\x32*.kaskada.errdetails.v1alpha.FenlDiagnosticR\x0f\x66\x65nlDiagnostics\x12\x1d\n\nnum_errors\x18\x02 \x01(\x03R\tnumErrors\"\xc7\x01\n\x0e\x46\x65nlDiagnostic\x12@\n\x08severity\x18\x01 \x01(\x0e\x32$.kaskada.errdetails.v1alpha.SeverityR\x08severity\x12\x12\n\x04\x63ode\x18\x02 \x01(\tR\x04\x63ode\x12\x18\n\x07message\x18\x03 \x01(\tR\x07message\x12\'\n\x0fsource_location\x18\x04 \x01(\tR\x0esourceLocation\x12\x1c\n\tformatted\x18\x05 \x01(\tR\tformatted*\x86\x01\n\x08Severity\x12\x18\n\x14SEVERITY_UNSPECIFIED\x10\x00\x12\x10\n\x0cSEVERITY_BUG\x10\x01\x12\x12\n\x0eSEVERITY_ERROR\x10\x02\x12\x14\n\x10SEVERITY_WARNING\x10\x03\x12\x11\n\rSEVERITY_NOTE\x10\x04\x12\x11\n\rSEVERITY_HELP\x10\x05\x42\x65\n\x1e\x63om.kaskada.errdetails.v1alphaP\x01ZAgitlab.com/kaskada/kaskada/wren/gen/go/kaskada/errdetails/v1alphab\x06proto3'
)

_SEVERITY = _descriptor.EnumDescriptor(
  name='Severity',
  full_name='kaskada.errdetails.v1alpha.Severity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_BUG', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_ERROR', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_WARNING', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_NOTE', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SEVERITY_HELP', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=422,
  serialized_end=556,
)
_sym_db.RegisterEnumDescriptor(_SEVERITY)

Severity = enum_type_wrapper.EnumTypeWrapper(_SEVERITY)
SEVERITY_UNSPECIFIED = 0
SEVERITY_BUG = 1
SEVERITY_ERROR = 2
SEVERITY_WARNING = 3
SEVERITY_NOTE = 4
SEVERITY_HELP = 5



_FENLDIAGNOSTICS = _descriptor.Descriptor(
  name='FenlDiagnostics',
  full_name='kaskada.errdetails.v1alpha.FenlDiagnostics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fenl_diagnostics', full_name='kaskada.errdetails.v1alpha.FenlDiagnostics.fenl_diagnostics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fenlDiagnostics', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='num_errors', full_name='kaskada.errdetails.v1alpha.FenlDiagnostics.num_errors', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='numErrors', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=82,
  serialized_end=217,
)


_FENLDIAGNOSTIC = _descriptor.Descriptor(
  name='FenlDiagnostic',
  full_name='kaskada.errdetails.v1alpha.FenlDiagnostic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='severity', full_name='kaskada.errdetails.v1alpha.FenlDiagnostic.severity', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='severity', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='code', full_name='kaskada.errdetails.v1alpha.FenlDiagnostic.code', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='code', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='kaskada.errdetails.v1alpha.FenlDiagnostic.message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='message', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='source_location', full_name='kaskada.errdetails.v1alpha.FenlDiagnostic.source_location', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='sourceLocation', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='formatted', full_name='kaskada.errdetails.v1alpha.FenlDiagnostic.formatted', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='formatted', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=220,
  serialized_end=419,
)

_FENLDIAGNOSTICS.fields_by_name['fenl_diagnostics'].message_type = _FENLDIAGNOSTIC
_FENLDIAGNOSTIC.fields_by_name['severity'].enum_type = _SEVERITY
DESCRIPTOR.message_types_by_name['FenlDiagnostics'] = _FENLDIAGNOSTICS
DESCRIPTOR.message_types_by_name['FenlDiagnostic'] = _FENLDIAGNOSTIC
DESCRIPTOR.enum_types_by_name['Severity'] = _SEVERITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FenlDiagnostics = _reflection.GeneratedProtocolMessageType('FenlDiagnostics', (_message.Message,), {
  'DESCRIPTOR' : _FENLDIAGNOSTICS,
  '__module__' : 'kaskada.errdetails.v1alpha.fenl_diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.errdetails.v1alpha.FenlDiagnostics)
  })
_sym_db.RegisterMessage(FenlDiagnostics)

FenlDiagnostic = _reflection.GeneratedProtocolMessageType('FenlDiagnostic', (_message.Message,), {
  'DESCRIPTOR' : _FENLDIAGNOSTIC,
  '__module__' : 'kaskada.errdetails.v1alpha.fenl_diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.errdetails.v1alpha.FenlDiagnostic)
  })
_sym_db.RegisterMessage(FenlDiagnostic)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
