# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/view.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/view.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1ekaskada/api/v1alpha/view.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a kaskada/api/v1alpha/shared.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a\x17validate/validate.proto\"\xbb\x01\n\x04View\x12\x1d\n\x07view_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x06viewId\x12$\n\tview_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08viewName\x12\'\n\nexpression\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\nexpression\x12\x45\n\x0bresult_type\x18\x07 \x01(\x0b\x32\x1e.kaskada.fenl.v1alpha.DataTypeB\x04\xe2\x41\x01\x03R\nresultType\"*\n\x10ListViewsRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\"\x92\x01\n\x11ListViewsResponse\x12/\n\x05views\x18\x01 \x03(\x0b\x32\x19.kaskada.api.v1alpha.ViewR\x05views\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"6\n\x0eGetViewRequest\x12$\n\tview_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08viewName\"\x8e\x01\n\x0fGetViewResponse\x12-\n\x04view\x18\x01 \x01(\x0b\x32\x19.kaskada.api.v1alpha.ViewR\x04view\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"L\n\x11\x43reateViewRequest\x12\x37\n\x04view\x18\x01 \x01(\x0b\x32\x19.kaskada.api.v1alpha.ViewB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x04view\"\xcc\x01\n\x12\x43reateViewResponse\x12-\n\x04view\x18\x01 \x01(\x0b\x32\x19.kaskada.api.v1alpha.ViewR\x04view\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\x12\x39\n\x08\x61nalysis\x18\x03 \x01(\x0b\x32\x1d.kaskada.api.v1alpha.AnalysisR\x08\x61nalysis\"9\n\x11\x44\x65leteViewRequest\x12$\n\tview_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08viewName\"b\n\x12\x44\x65leteViewResponse\x12L\n\x0frequest_details\x18\x01 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\x80\x04\n\x0bViewService\x12r\n\tListViews\x12%.kaskada.api.v1alpha.ListViewsRequest\x1a&.kaskada.api.v1alpha.ListViewsResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/v1alpha/views\x12z\n\x07GetView\x12#.kaskada.api.v1alpha.GetViewRequest\x1a$.kaskada.api.v1alpha.GetViewResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/v1alpha/views/{view_name=*}\x12{\n\nCreateView\x12&.kaskada.api.v1alpha.CreateViewRequest\x1a\'.kaskada.api.v1alpha.CreateViewResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x0e/v1alpha/views:\x04view\x12\x83\x01\n\nDeleteView\x12&.kaskada.api.v1alpha.DeleteViewRequest\x1a\'.kaskada.api.v1alpha.DeleteViewResponse\"$\x82\xd3\xe4\x93\x02\x1e*\x1c/v1alpha/views/{view_name=*}BV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_VIEW = _descriptor.Descriptor(
  name='View',
  full_name='kaskada.api.v1alpha.View',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view_id', full_name='kaskada.api.v1alpha.View.view_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='viewId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='view_name', full_name='kaskada.api.v1alpha.View.view_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='viewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='expression', full_name='kaskada.api.v1alpha.View.expression', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='expression', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_type', full_name='kaskada.api.v1alpha.View.result_type', index=3,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='resultType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=213,
  serialized_end=400,
)


_LISTVIEWSREQUEST = _descriptor.Descriptor(
  name='ListViewsRequest',
  full_name='kaskada.api.v1alpha.ListViewsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search', full_name='kaskada.api.v1alpha.ListViewsRequest.search', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='search', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=402,
  serialized_end=444,
)


_LISTVIEWSRESPONSE = _descriptor.Descriptor(
  name='ListViewsResponse',
  full_name='kaskada.api.v1alpha.ListViewsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='views', full_name='kaskada.api.v1alpha.ListViewsResponse.views', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='views', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.ListViewsResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=447,
  serialized_end=593,
)


_GETVIEWREQUEST = _descriptor.Descriptor(
  name='GetViewRequest',
  full_name='kaskada.api.v1alpha.GetViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view_name', full_name='kaskada.api.v1alpha.GetViewRequest.view_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='viewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=595,
  serialized_end=649,
)


_GETVIEWRESPONSE = _descriptor.Descriptor(
  name='GetViewResponse',
  full_name='kaskada.api.v1alpha.GetViewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view', full_name='kaskada.api.v1alpha.GetViewResponse.view', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='view', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.GetViewResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=652,
  serialized_end=794,
)


_CREATEVIEWREQUEST = _descriptor.Descriptor(
  name='CreateViewRequest',
  full_name='kaskada.api.v1alpha.CreateViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view', full_name='kaskada.api.v1alpha.CreateViewRequest.view', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', json_name='view', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=796,
  serialized_end=872,
)


_CREATEVIEWRESPONSE = _descriptor.Descriptor(
  name='CreateViewResponse',
  full_name='kaskada.api.v1alpha.CreateViewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view', full_name='kaskada.api.v1alpha.CreateViewResponse.view', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='view', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.CreateViewResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='analysis', full_name='kaskada.api.v1alpha.CreateViewResponse.analysis', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='analysis', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=875,
  serialized_end=1079,
)


_DELETEVIEWREQUEST = _descriptor.Descriptor(
  name='DeleteViewRequest',
  full_name='kaskada.api.v1alpha.DeleteViewRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='view_name', full_name='kaskada.api.v1alpha.DeleteViewRequest.view_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='viewName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1081,
  serialized_end=1138,
)


_DELETEVIEWRESPONSE = _descriptor.Descriptor(
  name='DeleteViewResponse',
  full_name='kaskada.api.v1alpha.DeleteViewResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.DeleteViewResponse.request_details', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1140,
  serialized_end=1238,
)

_VIEW.fields_by_name['result_type'].message_type = kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2._DATATYPE
_LISTVIEWSRESPONSE.fields_by_name['views'].message_type = _VIEW
_LISTVIEWSRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_GETVIEWRESPONSE.fields_by_name['view'].message_type = _VIEW
_GETVIEWRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_CREATEVIEWREQUEST.fields_by_name['view'].message_type = _VIEW
_CREATEVIEWRESPONSE.fields_by_name['view'].message_type = _VIEW
_CREATEVIEWRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_CREATEVIEWRESPONSE.fields_by_name['analysis'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._ANALYSIS
_DELETEVIEWRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
DESCRIPTOR.message_types_by_name['View'] = _VIEW
DESCRIPTOR.message_types_by_name['ListViewsRequest'] = _LISTVIEWSREQUEST
DESCRIPTOR.message_types_by_name['ListViewsResponse'] = _LISTVIEWSRESPONSE
DESCRIPTOR.message_types_by_name['GetViewRequest'] = _GETVIEWREQUEST
DESCRIPTOR.message_types_by_name['GetViewResponse'] = _GETVIEWRESPONSE
DESCRIPTOR.message_types_by_name['CreateViewRequest'] = _CREATEVIEWREQUEST
DESCRIPTOR.message_types_by_name['CreateViewResponse'] = _CREATEVIEWRESPONSE
DESCRIPTOR.message_types_by_name['DeleteViewRequest'] = _DELETEVIEWREQUEST
DESCRIPTOR.message_types_by_name['DeleteViewResponse'] = _DELETEVIEWRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

View = _reflection.GeneratedProtocolMessageType('View', (_message.Message,), {
  'DESCRIPTOR' : _VIEW,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.View)
  })
_sym_db.RegisterMessage(View)

ListViewsRequest = _reflection.GeneratedProtocolMessageType('ListViewsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIEWSREQUEST,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListViewsRequest)
  })
_sym_db.RegisterMessage(ListViewsRequest)

ListViewsResponse = _reflection.GeneratedProtocolMessageType('ListViewsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTVIEWSRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListViewsResponse)
  })
_sym_db.RegisterMessage(ListViewsResponse)

GetViewRequest = _reflection.GeneratedProtocolMessageType('GetViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETVIEWREQUEST,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetViewRequest)
  })
_sym_db.RegisterMessage(GetViewRequest)

GetViewResponse = _reflection.GeneratedProtocolMessageType('GetViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETVIEWRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetViewResponse)
  })
_sym_db.RegisterMessage(GetViewResponse)

CreateViewRequest = _reflection.GeneratedProtocolMessageType('CreateViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIEWREQUEST,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateViewRequest)
  })
_sym_db.RegisterMessage(CreateViewRequest)

CreateViewResponse = _reflection.GeneratedProtocolMessageType('CreateViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEVIEWRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateViewResponse)
  })
_sym_db.RegisterMessage(CreateViewResponse)

DeleteViewRequest = _reflection.GeneratedProtocolMessageType('DeleteViewRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIEWREQUEST,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteViewRequest)
  })
_sym_db.RegisterMessage(DeleteViewRequest)

DeleteViewResponse = _reflection.GeneratedProtocolMessageType('DeleteViewResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEVIEWRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.view_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteViewResponse)
  })
_sym_db.RegisterMessage(DeleteViewResponse)


DESCRIPTOR._options = None
_VIEW.fields_by_name['view_id']._options = None
_VIEW.fields_by_name['view_name']._options = None
_VIEW.fields_by_name['expression']._options = None
_VIEW.fields_by_name['result_type']._options = None
_GETVIEWREQUEST.fields_by_name['view_name']._options = None
_CREATEVIEWREQUEST.fields_by_name['view']._options = None
_DELETEVIEWREQUEST.fields_by_name['view_name']._options = None

_VIEWSERVICE = _descriptor.ServiceDescriptor(
  name='ViewService',
  full_name='kaskada.api.v1alpha.ViewService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1241,
  serialized_end=1753,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListViews',
    full_name='kaskada.api.v1alpha.ViewService.ListViews',
    index=0,
    containing_service=None,
    input_type=_LISTVIEWSREQUEST,
    output_type=_LISTVIEWSRESPONSE,
    serialized_options=b'\202\323\344\223\002\020\022\016/v1alpha/views',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetView',
    full_name='kaskada.api.v1alpha.ViewService.GetView',
    index=1,
    containing_service=None,
    input_type=_GETVIEWREQUEST,
    output_type=_GETVIEWRESPONSE,
    serialized_options=b'\202\323\344\223\002\036\022\034/v1alpha/views/{view_name=*}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateView',
    full_name='kaskada.api.v1alpha.ViewService.CreateView',
    index=2,
    containing_service=None,
    input_type=_CREATEVIEWREQUEST,
    output_type=_CREATEVIEWRESPONSE,
    serialized_options=b'\202\323\344\223\002\026\"\016/v1alpha/views:\004view',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteView',
    full_name='kaskada.api.v1alpha.ViewService.DeleteView',
    index=3,
    containing_service=None,
    input_type=_DELETEVIEWREQUEST,
    output_type=_DELETEVIEWRESPONSE,
    serialized_options=b'\202\323\344\223\002\036*\034/v1alpha/views/{view_name=*}',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_VIEWSERVICE)

DESCRIPTOR.services_by_name['ViewService'] = _VIEWSERVICE

# @@protoc_insertion_point(module_scope)
