# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/staged_file.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/staged_file.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%kaskada/api/v1alpha/staged_file.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a kaskada/api/v1alpha/shared.proto\x1a\x17validate/validate.proto\"\xff\x02\n\nStagedFile\x12\x1d\n\x07\x66ile_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x06\x66ileId\x12$\n\tfile_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x08\x66ileName\x12\x41\n\x0b\x63reate_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12T\n\x15upload_completed_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\x13uploadCompletedTime\x12*\n\ncontent_id\x18\x05 \x01(\tB\x0b\xfa\x42\x08r\x06\x98\x01 \xd0\x01\x01R\tcontentId\x12+\n\x0e\x63ontent_length\x18\x06 \x01(\x03\x42\x04\xe2\x41\x01\x03R\rcontentLength\x12:\n\x06schema\x18\x07 \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaB\x04\xe2\x41\x01\x03R\x06schema\"x\n\x16ListStagedFilesRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xc6\x01\n\x17ListStagedFilesResponse\x12\x35\n\x05\x66iles\x18\x01 \x03(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileR\x05\x66iles\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"8\n\x14GetStagedFileRequest\x12 \n\x07\x66ile_id\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x06\x66ileId\"\x9a\x01\n\x15GetStagedFileResponse\x12\x33\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileR\x04\x66ile\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"X\n\x17\x43reateStagedFileRequest\x12=\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x04\x66ile\"\xaf\x01\n\x18\x43reateStagedFileResponse\x12\x33\n\x04\x66ile\x18\x01 \x01(\x0b\x32\x1f.kaskada.api.v1alpha.StagedFileR\x04\x66ile\x12\x10\n\x03url\x18\x02 \x01(\tR\x03url\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\xcc\x03\n\x11StagedFileService\x12\x8b\x01\n\x0fListStagedFiles\x12+.kaskada.api.v1alpha.ListStagedFilesRequest\x1a,.kaskada.api.v1alpha.ListStagedFilesResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/v1alpha/staged_files\x12\x91\x01\n\rGetStagedFile\x12).kaskada.api.v1alpha.GetStagedFileRequest\x1a*.kaskada.api.v1alpha.GetStagedFileResponse\")\x82\xd3\xe4\x93\x02#\x12!/v1alpha/staged_files/{file_id=*}\x12\x94\x01\n\x10\x43reateStagedFile\x12,.kaskada.api.v1alpha.CreateStagedFileRequest\x1a-.kaskada.api.v1alpha.CreateStagedFileResponse\"#\x82\xd3\xe4\x93\x02\x1d\"\x15/v1alpha/staged_files:\x04\x66ileBV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_STAGEDFILE = _descriptor.Descriptor(
  name='StagedFile',
  full_name='kaskada.api.v1alpha.StagedFile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_id', full_name='kaskada.api.v1alpha.StagedFile.file_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='fileId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_name', full_name='kaskada.api.v1alpha.StagedFile.file_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='fileName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='kaskada.api.v1alpha.StagedFile.create_time', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='createTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='upload_completed_time', full_name='kaskada.api.v1alpha.StagedFile.upload_completed_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='uploadCompletedTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_id', full_name='kaskada.api.v1alpha.StagedFile.content_id', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\010r\006\230\001 \320\001\001', json_name='contentId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content_length', full_name='kaskada.api.v1alpha.StagedFile.content_length', index=5,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='contentLength', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='kaskada.api.v1alpha.StagedFile.schema', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=253,
  serialized_end=636,
)


_LISTSTAGEDFILESREQUEST = _descriptor.Descriptor(
  name='ListStagedFilesRequest',
  full_name='kaskada.api.v1alpha.ListStagedFilesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search', full_name='kaskada.api.v1alpha.ListStagedFilesRequest.search', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='search', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='kaskada.api.v1alpha.ListStagedFilesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\032\005\030\350\007(\000', json_name='pageSize', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='kaskada.api.v1alpha.ListStagedFilesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pageToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=638,
  serialized_end=758,
)


_LISTSTAGEDFILESRESPONSE = _descriptor.Descriptor(
  name='ListStagedFilesResponse',
  full_name='kaskada.api.v1alpha.ListStagedFilesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='kaskada.api.v1alpha.ListStagedFilesResponse.files', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='files', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='kaskada.api.v1alpha.ListStagedFilesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nextPageToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.ListStagedFilesResponse.request_details', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=761,
  serialized_end=959,
)


_GETSTAGEDFILEREQUEST = _descriptor.Descriptor(
  name='GetStagedFileRequest',
  full_name='kaskada.api.v1alpha.GetStagedFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_id', full_name='kaskada.api.v1alpha.GetStagedFileRequest.file_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='fileId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=961,
  serialized_end=1017,
)


_GETSTAGEDFILERESPONSE = _descriptor.Descriptor(
  name='GetStagedFileResponse',
  full_name='kaskada.api.v1alpha.GetStagedFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='kaskada.api.v1alpha.GetStagedFileResponse.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='file', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.GetStagedFileResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1020,
  serialized_end=1174,
)


_CREATESTAGEDFILEREQUEST = _descriptor.Descriptor(
  name='CreateStagedFileRequest',
  full_name='kaskada.api.v1alpha.CreateStagedFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='kaskada.api.v1alpha.CreateStagedFileRequest.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', json_name='file', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1176,
  serialized_end=1264,
)


_CREATESTAGEDFILERESPONSE = _descriptor.Descriptor(
  name='CreateStagedFileResponse',
  full_name='kaskada.api.v1alpha.CreateStagedFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='kaskada.api.v1alpha.CreateStagedFileResponse.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='file', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url', full_name='kaskada.api.v1alpha.CreateStagedFileResponse.url', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='url', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.CreateStagedFileResponse.request_details', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1267,
  serialized_end=1442,
)

_STAGEDFILE.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STAGEDFILE.fields_by_name['upload_completed_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STAGEDFILE.fields_by_name['schema'].message_type = kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2._SCHEMA
_LISTSTAGEDFILESRESPONSE.fields_by_name['files'].message_type = _STAGEDFILE
_LISTSTAGEDFILESRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_GETSTAGEDFILERESPONSE.fields_by_name['file'].message_type = _STAGEDFILE
_GETSTAGEDFILERESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_CREATESTAGEDFILEREQUEST.fields_by_name['file'].message_type = _STAGEDFILE
_CREATESTAGEDFILERESPONSE.fields_by_name['file'].message_type = _STAGEDFILE
_CREATESTAGEDFILERESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
DESCRIPTOR.message_types_by_name['StagedFile'] = _STAGEDFILE
DESCRIPTOR.message_types_by_name['ListStagedFilesRequest'] = _LISTSTAGEDFILESREQUEST
DESCRIPTOR.message_types_by_name['ListStagedFilesResponse'] = _LISTSTAGEDFILESRESPONSE
DESCRIPTOR.message_types_by_name['GetStagedFileRequest'] = _GETSTAGEDFILEREQUEST
DESCRIPTOR.message_types_by_name['GetStagedFileResponse'] = _GETSTAGEDFILERESPONSE
DESCRIPTOR.message_types_by_name['CreateStagedFileRequest'] = _CREATESTAGEDFILEREQUEST
DESCRIPTOR.message_types_by_name['CreateStagedFileResponse'] = _CREATESTAGEDFILERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StagedFile = _reflection.GeneratedProtocolMessageType('StagedFile', (_message.Message,), {
  'DESCRIPTOR' : _STAGEDFILE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.StagedFile)
  })
_sym_db.RegisterMessage(StagedFile)

ListStagedFilesRequest = _reflection.GeneratedProtocolMessageType('ListStagedFilesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTAGEDFILESREQUEST,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListStagedFilesRequest)
  })
_sym_db.RegisterMessage(ListStagedFilesRequest)

ListStagedFilesResponse = _reflection.GeneratedProtocolMessageType('ListStagedFilesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTAGEDFILESRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListStagedFilesResponse)
  })
_sym_db.RegisterMessage(ListStagedFilesResponse)

GetStagedFileRequest = _reflection.GeneratedProtocolMessageType('GetStagedFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTAGEDFILEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetStagedFileRequest)
  })
_sym_db.RegisterMessage(GetStagedFileRequest)

GetStagedFileResponse = _reflection.GeneratedProtocolMessageType('GetStagedFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTAGEDFILERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetStagedFileResponse)
  })
_sym_db.RegisterMessage(GetStagedFileResponse)

CreateStagedFileRequest = _reflection.GeneratedProtocolMessageType('CreateStagedFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTAGEDFILEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateStagedFileRequest)
  })
_sym_db.RegisterMessage(CreateStagedFileRequest)

CreateStagedFileResponse = _reflection.GeneratedProtocolMessageType('CreateStagedFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTAGEDFILERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.staged_file_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateStagedFileResponse)
  })
_sym_db.RegisterMessage(CreateStagedFileResponse)


DESCRIPTOR._options = None
_STAGEDFILE.fields_by_name['file_id']._options = None
_STAGEDFILE.fields_by_name['file_name']._options = None
_STAGEDFILE.fields_by_name['create_time']._options = None
_STAGEDFILE.fields_by_name['upload_completed_time']._options = None
_STAGEDFILE.fields_by_name['content_id']._options = None
_STAGEDFILE.fields_by_name['content_length']._options = None
_STAGEDFILE.fields_by_name['schema']._options = None
_LISTSTAGEDFILESREQUEST.fields_by_name['page_size']._options = None
_GETSTAGEDFILEREQUEST.fields_by_name['file_id']._options = None
_CREATESTAGEDFILEREQUEST.fields_by_name['file']._options = None

_STAGEDFILESERVICE = _descriptor.ServiceDescriptor(
  name='StagedFileService',
  full_name='kaskada.api.v1alpha.StagedFileService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=1445,
  serialized_end=1905,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListStagedFiles',
    full_name='kaskada.api.v1alpha.StagedFileService.ListStagedFiles',
    index=0,
    containing_service=None,
    input_type=_LISTSTAGEDFILESREQUEST,
    output_type=_LISTSTAGEDFILESRESPONSE,
    serialized_options=b'\202\323\344\223\002\027\022\025/v1alpha/staged_files',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetStagedFile',
    full_name='kaskada.api.v1alpha.StagedFileService.GetStagedFile',
    index=1,
    containing_service=None,
    input_type=_GETSTAGEDFILEREQUEST,
    output_type=_GETSTAGEDFILERESPONSE,
    serialized_options=b'\202\323\344\223\002#\022!/v1alpha/staged_files/{file_id=*}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateStagedFile',
    full_name='kaskada.api.v1alpha.StagedFileService.CreateStagedFile',
    index=2,
    containing_service=None,
    input_type=_CREATESTAGEDFILEREQUEST,
    output_type=_CREATESTAGEDFILERESPONSE,
    serialized_options=b'\202\323\344\223\002\035\"\025/v1alpha/staged_files:\004file',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_STAGEDFILESERVICE)

DESCRIPTOR.services_by_name['StagedFileService'] = _STAGEDFILESERVICE

# @@protoc_insertion_point(module_scope)
