# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/fenl/v1alpha/schema.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/fenl/v1alpha/schema.proto',
  package='kaskada.fenl.v1alpha',
  syntax='proto3',
  serialized_options=b'Z;gitlab.com/kaskada/kaskada/wren/gen/go/kaskada/fenl/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n!kaskada/fenl/v1alpha/schema.proto\x12\x14kaskada.fenl.v1alpha\x1a\x1bgoogle/protobuf/empty.proto\"\xdd\x07\n\x08\x44\x61taType\x12L\n\tprimitive\x18\x01 \x01(\x0e\x32,.kaskada.fenl.v1alpha.DataType.PrimitiveTypeH\x00R\tprimitive\x12\x36\n\x06struct\x18\x02 \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaH\x00R\x06struct\x12\x30\n\x06window\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x06window\"\x90\x06\n\rPrimitiveType\x12\x1e\n\x1aPRIMITIVE_TYPE_UNSPECIFIED\x10\x00\x12\x17\n\x13PRIMITIVE_TYPE_NULL\x10\x01\x12\x17\n\x13PRIMITIVE_TYPE_BOOL\x10\x02\x12\x15\n\x11PRIMITIVE_TYPE_I8\x10\x03\x12\x16\n\x12PRIMITIVE_TYPE_I16\x10\x04\x12\x16\n\x12PRIMITIVE_TYPE_I32\x10\x05\x12\x16\n\x12PRIMITIVE_TYPE_I64\x10\x06\x12\x15\n\x11PRIMITIVE_TYPE_U8\x10\x07\x12\x16\n\x12PRIMITIVE_TYPE_U16\x10\x08\x12\x16\n\x12PRIMITIVE_TYPE_U32\x10\t\x12\x16\n\x12PRIMITIVE_TYPE_U64\x10\n\x12\x16\n\x12PRIMITIVE_TYPE_F16\x10\x0b\x12\x16\n\x12PRIMITIVE_TYPE_F32\x10\x0c\x12\x16\n\x12PRIMITIVE_TYPE_F64\x10\r\x12\x19\n\x15PRIMITIVE_TYPE_STRING\x10\x0e\x12$\n PRIMITIVE_TYPE_INTERVAL_DAY_TIME\x10\x0f\x12&\n\"PRIMITIVE_TYPE_INTERVAL_YEAR_MONTH\x10\x10\x12\"\n\x1ePRIMITIVE_TYPE_DURATION_SECOND\x10\x11\x12\'\n#PRIMITIVE_TYPE_DURATION_MILLISECOND\x10\x12\x12\'\n#PRIMITIVE_TYPE_DURATION_MICROSECOND\x10\x13\x12&\n\"PRIMITIVE_TYPE_DURATION_NANOSECOND\x10\x14\x12#\n\x1fPRIMITIVE_TYPE_TIMESTAMP_SECOND\x10\x15\x12(\n$PRIMITIVE_TYPE_TIMESTAMP_MILLISECOND\x10\x16\x12(\n$PRIMITIVE_TYPE_TIMESTAMP_MICROSECOND\x10\x17\x12\'\n#PRIMITIVE_TYPE_TIMESTAMP_NANOSECOND\x10\x18\x42\x06\n\x04kind\"\x9e\x01\n\x06Schema\x12:\n\x06\x66ields\x18\x01 \x03(\x0b\x32\".kaskada.fenl.v1alpha.Schema.FieldR\x06\x66ields\x1aX\n\x05\x46ield\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12;\n\tdata_type\x18\x02 \x01(\x0b\x32\x1e.kaskada.fenl.v1alpha.DataTypeR\x08\x64\x61taTypeB=Z;gitlab.com/kaskada/kaskada/wren/gen/go/kaskada/fenl/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,])



_DATATYPE_PRIMITIVETYPE = _descriptor.EnumDescriptor(
  name='PrimitiveType',
  full_name='kaskada.fenl.v1alpha.DataType.PrimitiveType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_NULL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_BOOL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_I8', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_I16', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_I32', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_I64', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_U8', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_U16', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_U32', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_U64', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_F16', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_F32', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_F64', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_STRING', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_INTERVAL_DAY_TIME', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_INTERVAL_YEAR_MONTH', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_DURATION_SECOND', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_DURATION_MILLISECOND', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_DURATION_MICROSECOND', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_DURATION_NANOSECOND', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_TIMESTAMP_SECOND', index=21, number=21,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_TIMESTAMP_MILLISECOND', index=22, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_TIMESTAMP_MICROSECOND', index=23, number=23,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PRIMITIVE_TYPE_TIMESTAMP_NANOSECOND', index=24, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=286,
  serialized_end=1070,
)
_sym_db.RegisterEnumDescriptor(_DATATYPE_PRIMITIVETYPE)


_DATATYPE = _descriptor.Descriptor(
  name='DataType',
  full_name='kaskada.fenl.v1alpha.DataType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='primitive', full_name='kaskada.fenl.v1alpha.DataType.primitive', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='primitive', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='struct', full_name='kaskada.fenl.v1alpha.DataType.struct', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='struct', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window', full_name='kaskada.fenl.v1alpha.DataType.window', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='window', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATATYPE_PRIMITIVETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='kind', full_name='kaskada.fenl.v1alpha.DataType.kind',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=89,
  serialized_end=1078,
)


_SCHEMA_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='kaskada.fenl.v1alpha.Schema.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='kaskada.fenl.v1alpha.Schema.Field.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_type', full_name='kaskada.fenl.v1alpha.Schema.Field.data_type', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataType', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1151,
  serialized_end=1239,
)

_SCHEMA = _descriptor.Descriptor(
  name='Schema',
  full_name='kaskada.fenl.v1alpha.Schema',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='fields', full_name='kaskada.fenl.v1alpha.Schema.fields', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fields', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SCHEMA_FIELD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1081,
  serialized_end=1239,
)

_DATATYPE.fields_by_name['primitive'].enum_type = _DATATYPE_PRIMITIVETYPE
_DATATYPE.fields_by_name['struct'].message_type = _SCHEMA
_DATATYPE.fields_by_name['window'].message_type = google_dot_protobuf_dot_empty__pb2._EMPTY
_DATATYPE_PRIMITIVETYPE.containing_type = _DATATYPE
_DATATYPE.oneofs_by_name['kind'].fields.append(
  _DATATYPE.fields_by_name['primitive'])
_DATATYPE.fields_by_name['primitive'].containing_oneof = _DATATYPE.oneofs_by_name['kind']
_DATATYPE.oneofs_by_name['kind'].fields.append(
  _DATATYPE.fields_by_name['struct'])
_DATATYPE.fields_by_name['struct'].containing_oneof = _DATATYPE.oneofs_by_name['kind']
_DATATYPE.oneofs_by_name['kind'].fields.append(
  _DATATYPE.fields_by_name['window'])
_DATATYPE.fields_by_name['window'].containing_oneof = _DATATYPE.oneofs_by_name['kind']
_SCHEMA_FIELD.fields_by_name['data_type'].message_type = _DATATYPE
_SCHEMA_FIELD.containing_type = _SCHEMA
_SCHEMA.fields_by_name['fields'].message_type = _SCHEMA_FIELD
DESCRIPTOR.message_types_by_name['DataType'] = _DATATYPE
DESCRIPTOR.message_types_by_name['Schema'] = _SCHEMA
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataType = _reflection.GeneratedProtocolMessageType('DataType', (_message.Message,), {
  'DESCRIPTOR' : _DATATYPE,
  '__module__' : 'kaskada.fenl.v1alpha.schema_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.fenl.v1alpha.DataType)
  })
_sym_db.RegisterMessage(DataType)

Schema = _reflection.GeneratedProtocolMessageType('Schema', (_message.Message,), {

  'Field' : _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), {
    'DESCRIPTOR' : _SCHEMA_FIELD,
    '__module__' : 'kaskada.fenl.v1alpha.schema_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.fenl.v1alpha.Schema.Field)
    })
  ,
  'DESCRIPTOR' : _SCHEMA,
  '__module__' : 'kaskada.fenl.v1alpha.schema_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.fenl.v1alpha.Schema)
  })
_sym_db.RegisterMessage(Schema)
_sym_db.RegisterMessage(Schema.Field)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
