# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/api/v1alpha/table.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaskada.api.v1alpha import shared_pb2 as kaskada_dot_api_dot_v1alpha_dot_shared__pb2
from kaskada.fenl.v1alpha import schema_pb2 as kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2
from validate import validate_pb2 as validate_dot_validate__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/api/v1alpha/table.proto',
  package='kaskada.api.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\027com.kaskada.api.v1alphaP\001Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1fkaskada/api/v1alpha/table.proto\x12\x13kaskada.api.v1alpha\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a kaskada/api/v1alpha/shared.proto\x1a!kaskada/fenl/v1alpha/schema.proto\x1a\x17validate/validate.proto\"\xd3\x04\n\x05Table\x12\x1f\n\x08table_id\x18\x01 \x01(\tB\x04\xe2\x41\x01\x03R\x07tableId\x12&\n\ntable_name\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\x12\x31\n\x10time_column_name\x18\x03 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x0etimeColumnName\x12<\n\x16\x65ntity_key_column_name\x18\x04 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x13\x65ntityKeyColumnName\x12\x37\n\x13subsort_column_name\x18\x05 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\x11subsortColumnName\x12\x1f\n\x0bgrouping_id\x18\x07 \x01(\tR\ngroupingId\x12\x41\n\x0b\x63reate_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x41\n\x0bupdate_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\nupdateTime\x12\x1e\n\x07version\x18\n \x01(\x05\x42\x04\xe2\x41\x01\x03R\x07version\x12#\n\nold_schema\x18\x0b \x01(\tB\x04\xe2\x41\x01\x03R\toldSchema\x12:\n\x06schema\x18\r \x01(\x0b\x32\x1c.kaskada.fenl.v1alpha.SchemaB\x04\xe2\x41\x01\x03R\x06schema\x12#\n\nfile_count\x18\x0e \x01(\x03\x42\x04\xe2\x41\x01\x03R\tfileCountJ\x04\x08\x06\x10\x07J\x04\x08\x0c\x10\r\"|\n\nSourceData\x12:\n\x04\x66ile\x18\x01 \x01(\x0b\x32$.kaskada.api.v1alpha.SourceData.FileH\x00R\x04\x66ile\x1a*\n\x04\x46ile\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x0e\n\x02id\x18\x02 \x01(\tR\x02idB\x06\n\x04\x64\x61ta\"\x96\x02\n\x13TableVersionDetails\x12\x18\n\x07version\x18\x01 \x01(\x05R\x07version\x12\x41\n\x0b\x63reate_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\x04\xe2\x41\x01\x03R\ncreateTime\x12\x1c\n\x06schema\x18\x03 \x01(\tB\x04\xe2\x41\x01\x03R\x06schema\x12P\n\nfile_infos\x18\x05 \x03(\x0b\x32\x31.kaskada.api.v1alpha.TableVersionDetails.FileInfoR\tfileInfos\x1a,\n\x08\x46ileInfo\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x10\n\x03key\x18\x02 \x01(\tR\x03keyJ\x04\x08\x04\x10\x05\"s\n\x11ListTablesRequest\x12\x16\n\x06search\x18\x01 \x01(\tR\x06search\x12\'\n\tpage_size\x18\x02 \x01(\x05\x42\n\xfa\x42\x07\x1a\x05\x18\xe8\x07(\x00R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\xbe\x01\n\x12ListTablesResponse\x12\x32\n\x06tables\x18\x01 \x03(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x06tables\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12L\n\x0frequest_details\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"9\n\x0fGetTableRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\"\x92\x01\n\x10GetTableResponse\x12\x30\n\x05table\x18\x01 \x01(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x05table\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"P\n\x12\x43reateTableRequest\x12:\n\x05table\x18\x01 \x01(\x0b\x32\x1a.kaskada.api.v1alpha.TableB\x08\xfa\x42\x05\x8a\x01\x02\x10\x01R\x05table\"\x95\x01\n\x13\x43reateTableResponse\x12\x30\n\x05table\x18\x01 \x01(\x0b\x32\x1a.kaskada.api.v1alpha.TableR\x05table\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"<\n\x12\x44\x65leteTableRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\"\x87\x01\n\x13\x44\x65leteTableResponse\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails\"\xc2\x01\n\x0fLoadDataRequest\x12&\n\ntable_name\x18\x01 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01R\ttableName\x12\"\n\x07\x66ile_id\x18\x02 \x01(\tB\x07\xfa\x42\x04r\x02\x10\x01H\x00R\x06\x66ileId\x12O\n\x10\x65xternal_s3_file\x18\x03 \x01(\x0b\x32#.kaskada.api.v1alpha.ExternalS3FileH\x00R\x0e\x65xternalS3FileB\x12\n\x0bsource_data\x12\x03\xf8\x42\x01\"\x84\x01\n\x10LoadDataResponse\x12\"\n\rdata_token_id\x18\x01 \x01(\tR\x0b\x64\x61taTokenId\x12L\n\x0frequest_details\x18\x02 \x01(\x0b\x32#.kaskada.api.v1alpha.RequestDetailsR\x0erequestDetails2\x94\x05\n\x0cTableService\x12v\n\nListTables\x12&.kaskada.api.v1alpha.ListTablesRequest\x1a\'.kaskada.api.v1alpha.ListTablesResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/v1alpha/tables\x12\x7f\n\x08GetTable\x12$.kaskada.api.v1alpha.GetTableRequest\x1a%.kaskada.api.v1alpha.GetTableResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1alpha/tables/{table_name=*}\x12\x80\x01\n\x0b\x43reateTable\x12\'.kaskada.api.v1alpha.CreateTableRequest\x1a(.kaskada.api.v1alpha.CreateTableResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x0f/v1alpha/tables:\x05table\x12\x88\x01\n\x0b\x44\x65leteTable\x12\'.kaskada.api.v1alpha.DeleteTableRequest\x1a(.kaskada.api.v1alpha.DeleteTableResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/v1alpha/tables/{table_name=*}\x12}\n\x08LoadData\x12$.kaskada.api.v1alpha.LoadDataRequest\x1a%.kaskada.api.v1alpha.LoadDataResponse\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/v1alpha/tables/load_data:\x01*BV\n\x17\x63om.kaskada.api.v1alphaP\x01Z9gitlab.com/kaskada/kaskada/api/gen/go/kaskada/api/v1alphab\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,kaskada_dot_api_dot_v1alpha_dot_shared__pb2.DESCRIPTOR,kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2.DESCRIPTOR,validate_dot_validate__pb2.DESCRIPTOR,])




_TABLE = _descriptor.Descriptor(
  name='Table',
  full_name='kaskada.api.v1alpha.Table',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_id', full_name='kaskada.api.v1alpha.Table.table_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='tableId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='table_name', full_name='kaskada.api.v1alpha.Table.table_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='tableName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time_column_name', full_name='kaskada.api.v1alpha.Table.time_column_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='timeColumnName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='entity_key_column_name', full_name='kaskada.api.v1alpha.Table.entity_key_column_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='entityKeyColumnName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='subsort_column_name', full_name='kaskada.api.v1alpha.Table.subsort_column_name', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='subsortColumnName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grouping_id', full_name='kaskada.api.v1alpha.Table.grouping_id', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='groupingId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='kaskada.api.v1alpha.Table.create_time', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='createTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_time', full_name='kaskada.api.v1alpha.Table.update_time', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='updateTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='version', full_name='kaskada.api.v1alpha.Table.version', index=8,
      number=10, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='version', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='old_schema', full_name='kaskada.api.v1alpha.Table.old_schema', index=9,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='oldSchema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='kaskada.api.v1alpha.Table.schema', index=10,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_count', full_name='kaskada.api.v1alpha.Table.file_count', index=11,
      number=14, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='fileCount', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=247,
  serialized_end=842,
)


_SOURCEDATA_FILE = _descriptor.Descriptor(
  name='File',
  full_name='kaskada.api.v1alpha.SourceData.File',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='kaskada.api.v1alpha.SourceData.File.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='name', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='id', full_name='kaskada.api.v1alpha.SourceData.File.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=918,
  serialized_end=960,
)

_SOURCEDATA = _descriptor.Descriptor(
  name='SourceData',
  full_name='kaskada.api.v1alpha.SourceData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='file', full_name='kaskada.api.v1alpha.SourceData.file', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='file', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SOURCEDATA_FILE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='data', full_name='kaskada.api.v1alpha.SourceData.data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=844,
  serialized_end=968,
)


_TABLEVERSIONDETAILS_FILEINFO = _descriptor.Descriptor(
  name='FileInfo',
  full_name='kaskada.api.v1alpha.TableVersionDetails.FileInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='kaskada.api.v1alpha.TableVersionDetails.FileInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='id', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='key', full_name='kaskada.api.v1alpha.TableVersionDetails.FileInfo.key', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='key', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1199,
  serialized_end=1243,
)

_TABLEVERSIONDETAILS = _descriptor.Descriptor(
  name='TableVersionDetails',
  full_name='kaskada.api.v1alpha.TableVersionDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='kaskada.api.v1alpha.TableVersionDetails.version', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='version', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='create_time', full_name='kaskada.api.v1alpha.TableVersionDetails.create_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='createTime', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema', full_name='kaskada.api.v1alpha.TableVersionDetails.schema', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\342A\001\003', json_name='schema', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_infos', full_name='kaskada.api.v1alpha.TableVersionDetails.file_infos', index=3,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='fileInfos', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_TABLEVERSIONDETAILS_FILEINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=971,
  serialized_end=1249,
)


_LISTTABLESREQUEST = _descriptor.Descriptor(
  name='ListTablesRequest',
  full_name='kaskada.api.v1alpha.ListTablesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='search', full_name='kaskada.api.v1alpha.ListTablesRequest.search', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='search', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='kaskada.api.v1alpha.ListTablesRequest.page_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\007\032\005\030\350\007(\000', json_name='pageSize', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='kaskada.api.v1alpha.ListTablesRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='pageToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1251,
  serialized_end=1366,
)


_LISTTABLESRESPONSE = _descriptor.Descriptor(
  name='ListTablesResponse',
  full_name='kaskada.api.v1alpha.ListTablesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tables', full_name='kaskada.api.v1alpha.ListTablesResponse.tables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='tables', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='kaskada.api.v1alpha.ListTablesResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='nextPageToken', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.ListTablesResponse.request_details', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1369,
  serialized_end=1559,
)


_GETTABLEREQUEST = _descriptor.Descriptor(
  name='GetTableRequest',
  full_name='kaskada.api.v1alpha.GetTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_name', full_name='kaskada.api.v1alpha.GetTableRequest.table_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='tableName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1561,
  serialized_end=1618,
)


_GETTABLERESPONSE = _descriptor.Descriptor(
  name='GetTableResponse',
  full_name='kaskada.api.v1alpha.GetTableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='kaskada.api.v1alpha.GetTableResponse.table', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='table', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.GetTableResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1621,
  serialized_end=1767,
)


_CREATETABLEREQUEST = _descriptor.Descriptor(
  name='CreateTableRequest',
  full_name='kaskada.api.v1alpha.CreateTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='kaskada.api.v1alpha.CreateTableRequest.table', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\005\212\001\002\020\001', json_name='table', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1769,
  serialized_end=1849,
)


_CREATETABLERESPONSE = _descriptor.Descriptor(
  name='CreateTableResponse',
  full_name='kaskada.api.v1alpha.CreateTableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table', full_name='kaskada.api.v1alpha.CreateTableResponse.table', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='table', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.CreateTableResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1852,
  serialized_end=2001,
)


_DELETETABLEREQUEST = _descriptor.Descriptor(
  name='DeleteTableRequest',
  full_name='kaskada.api.v1alpha.DeleteTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_name', full_name='kaskada.api.v1alpha.DeleteTableRequest.table_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='tableName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2003,
  serialized_end=2063,
)


_DELETETABLERESPONSE = _descriptor.Descriptor(
  name='DeleteTableResponse',
  full_name='kaskada.api.v1alpha.DeleteTableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.DeleteTableResponse.data_token_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.DeleteTableResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2066,
  serialized_end=2201,
)


_LOADDATAREQUEST = _descriptor.Descriptor(
  name='LoadDataRequest',
  full_name='kaskada.api.v1alpha.LoadDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='table_name', full_name='kaskada.api.v1alpha.LoadDataRequest.table_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='tableName', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_id', full_name='kaskada.api.v1alpha.LoadDataRequest.file_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372B\004r\002\020\001', json_name='fileId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='external_s3_file', full_name='kaskada.api.v1alpha.LoadDataRequest.external_s3_file', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='externalS3File', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='source_data', full_name='kaskada.api.v1alpha.LoadDataRequest.source_data',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\370B\001'),
  ],
  serialized_start=2204,
  serialized_end=2398,
)


_LOADDATARESPONSE = _descriptor.Descriptor(
  name='LoadDataResponse',
  full_name='kaskada.api.v1alpha.LoadDataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_token_id', full_name='kaskada.api.v1alpha.LoadDataResponse.data_token_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='dataTokenId', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='request_details', full_name='kaskada.api.v1alpha.LoadDataResponse.request_details', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='requestDetails', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2401,
  serialized_end=2533,
)

_TABLE.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TABLE.fields_by_name['update_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TABLE.fields_by_name['schema'].message_type = kaskada_dot_fenl_dot_v1alpha_dot_schema__pb2._SCHEMA
_SOURCEDATA_FILE.containing_type = _SOURCEDATA
_SOURCEDATA.fields_by_name['file'].message_type = _SOURCEDATA_FILE
_SOURCEDATA.oneofs_by_name['data'].fields.append(
  _SOURCEDATA.fields_by_name['file'])
_SOURCEDATA.fields_by_name['file'].containing_oneof = _SOURCEDATA.oneofs_by_name['data']
_TABLEVERSIONDETAILS_FILEINFO.containing_type = _TABLEVERSIONDETAILS
_TABLEVERSIONDETAILS.fields_by_name['create_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TABLEVERSIONDETAILS.fields_by_name['file_infos'].message_type = _TABLEVERSIONDETAILS_FILEINFO
_LISTTABLESRESPONSE.fields_by_name['tables'].message_type = _TABLE
_LISTTABLESRESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_GETTABLERESPONSE.fields_by_name['table'].message_type = _TABLE
_GETTABLERESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_CREATETABLEREQUEST.fields_by_name['table'].message_type = _TABLE
_CREATETABLERESPONSE.fields_by_name['table'].message_type = _TABLE
_CREATETABLERESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_DELETETABLERESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
_LOADDATAREQUEST.fields_by_name['external_s3_file'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._EXTERNALS3FILE
_LOADDATAREQUEST.oneofs_by_name['source_data'].fields.append(
  _LOADDATAREQUEST.fields_by_name['file_id'])
_LOADDATAREQUEST.fields_by_name['file_id'].containing_oneof = _LOADDATAREQUEST.oneofs_by_name['source_data']
_LOADDATAREQUEST.oneofs_by_name['source_data'].fields.append(
  _LOADDATAREQUEST.fields_by_name['external_s3_file'])
_LOADDATAREQUEST.fields_by_name['external_s3_file'].containing_oneof = _LOADDATAREQUEST.oneofs_by_name['source_data']
_LOADDATARESPONSE.fields_by_name['request_details'].message_type = kaskada_dot_api_dot_v1alpha_dot_shared__pb2._REQUESTDETAILS
DESCRIPTOR.message_types_by_name['Table'] = _TABLE
DESCRIPTOR.message_types_by_name['SourceData'] = _SOURCEDATA
DESCRIPTOR.message_types_by_name['TableVersionDetails'] = _TABLEVERSIONDETAILS
DESCRIPTOR.message_types_by_name['ListTablesRequest'] = _LISTTABLESREQUEST
DESCRIPTOR.message_types_by_name['ListTablesResponse'] = _LISTTABLESRESPONSE
DESCRIPTOR.message_types_by_name['GetTableRequest'] = _GETTABLEREQUEST
DESCRIPTOR.message_types_by_name['GetTableResponse'] = _GETTABLERESPONSE
DESCRIPTOR.message_types_by_name['CreateTableRequest'] = _CREATETABLEREQUEST
DESCRIPTOR.message_types_by_name['CreateTableResponse'] = _CREATETABLERESPONSE
DESCRIPTOR.message_types_by_name['DeleteTableRequest'] = _DELETETABLEREQUEST
DESCRIPTOR.message_types_by_name['DeleteTableResponse'] = _DELETETABLERESPONSE
DESCRIPTOR.message_types_by_name['LoadDataRequest'] = _LOADDATAREQUEST
DESCRIPTOR.message_types_by_name['LoadDataResponse'] = _LOADDATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Table = _reflection.GeneratedProtocolMessageType('Table', (_message.Message,), {
  'DESCRIPTOR' : _TABLE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.Table)
  })
_sym_db.RegisterMessage(Table)

SourceData = _reflection.GeneratedProtocolMessageType('SourceData', (_message.Message,), {

  'File' : _reflection.GeneratedProtocolMessageType('File', (_message.Message,), {
    'DESCRIPTOR' : _SOURCEDATA_FILE,
    '__module__' : 'kaskada.api.v1alpha.table_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.SourceData.File)
    })
  ,
  'DESCRIPTOR' : _SOURCEDATA,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.SourceData)
  })
_sym_db.RegisterMessage(SourceData)
_sym_db.RegisterMessage(SourceData.File)

TableVersionDetails = _reflection.GeneratedProtocolMessageType('TableVersionDetails', (_message.Message,), {

  'FileInfo' : _reflection.GeneratedProtocolMessageType('FileInfo', (_message.Message,), {
    'DESCRIPTOR' : _TABLEVERSIONDETAILS_FILEINFO,
    '__module__' : 'kaskada.api.v1alpha.table_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.TableVersionDetails.FileInfo)
    })
  ,
  'DESCRIPTOR' : _TABLEVERSIONDETAILS,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.TableVersionDetails)
  })
_sym_db.RegisterMessage(TableVersionDetails)
_sym_db.RegisterMessage(TableVersionDetails.FileInfo)

ListTablesRequest = _reflection.GeneratedProtocolMessageType('ListTablesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListTablesRequest)
  })
_sym_db.RegisterMessage(ListTablesRequest)

ListTablesResponse = _reflection.GeneratedProtocolMessageType('ListTablesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTTABLESRESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.ListTablesResponse)
  })
_sym_db.RegisterMessage(ListTablesResponse)

GetTableRequest = _reflection.GeneratedProtocolMessageType('GetTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetTableRequest)
  })
_sym_db.RegisterMessage(GetTableRequest)

GetTableResponse = _reflection.GeneratedProtocolMessageType('GetTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETTABLERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.GetTableResponse)
  })
_sym_db.RegisterMessage(GetTableResponse)

CreateTableRequest = _reflection.GeneratedProtocolMessageType('CreateTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATETABLEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateTableRequest)
  })
_sym_db.RegisterMessage(CreateTableRequest)

CreateTableResponse = _reflection.GeneratedProtocolMessageType('CreateTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATETABLERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.CreateTableResponse)
  })
_sym_db.RegisterMessage(CreateTableResponse)

DeleteTableRequest = _reflection.GeneratedProtocolMessageType('DeleteTableRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETABLEREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteTableRequest)
  })
_sym_db.RegisterMessage(DeleteTableRequest)

DeleteTableResponse = _reflection.GeneratedProtocolMessageType('DeleteTableResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETETABLERESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.DeleteTableResponse)
  })
_sym_db.RegisterMessage(DeleteTableResponse)

LoadDataRequest = _reflection.GeneratedProtocolMessageType('LoadDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOADDATAREQUEST,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.LoadDataRequest)
  })
_sym_db.RegisterMessage(LoadDataRequest)

LoadDataResponse = _reflection.GeneratedProtocolMessageType('LoadDataResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOADDATARESPONSE,
  '__module__' : 'kaskada.api.v1alpha.table_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.api.v1alpha.LoadDataResponse)
  })
_sym_db.RegisterMessage(LoadDataResponse)


DESCRIPTOR._options = None
_TABLE.fields_by_name['table_id']._options = None
_TABLE.fields_by_name['table_name']._options = None
_TABLE.fields_by_name['time_column_name']._options = None
_TABLE.fields_by_name['entity_key_column_name']._options = None
_TABLE.fields_by_name['subsort_column_name']._options = None
_TABLE.fields_by_name['create_time']._options = None
_TABLE.fields_by_name['update_time']._options = None
_TABLE.fields_by_name['version']._options = None
_TABLE.fields_by_name['old_schema']._options = None
_TABLE.fields_by_name['schema']._options = None
_TABLE.fields_by_name['file_count']._options = None
_TABLEVERSIONDETAILS.fields_by_name['create_time']._options = None
_TABLEVERSIONDETAILS.fields_by_name['schema']._options = None
_LISTTABLESREQUEST.fields_by_name['page_size']._options = None
_GETTABLEREQUEST.fields_by_name['table_name']._options = None
_CREATETABLEREQUEST.fields_by_name['table']._options = None
_DELETETABLEREQUEST.fields_by_name['table_name']._options = None
_LOADDATAREQUEST.oneofs_by_name['source_data']._options = None
_LOADDATAREQUEST.fields_by_name['table_name']._options = None
_LOADDATAREQUEST.fields_by_name['file_id']._options = None

_TABLESERVICE = _descriptor.ServiceDescriptor(
  name='TableService',
  full_name='kaskada.api.v1alpha.TableService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=2536,
  serialized_end=3196,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListTables',
    full_name='kaskada.api.v1alpha.TableService.ListTables',
    index=0,
    containing_service=None,
    input_type=_LISTTABLESREQUEST,
    output_type=_LISTTABLESRESPONSE,
    serialized_options=b'\202\323\344\223\002\021\022\017/v1alpha/tables',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetTable',
    full_name='kaskada.api.v1alpha.TableService.GetTable',
    index=1,
    containing_service=None,
    input_type=_GETTABLEREQUEST,
    output_type=_GETTABLERESPONSE,
    serialized_options=b'\202\323\344\223\002 \022\036/v1alpha/tables/{table_name=*}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='CreateTable',
    full_name='kaskada.api.v1alpha.TableService.CreateTable',
    index=2,
    containing_service=None,
    input_type=_CREATETABLEREQUEST,
    output_type=_CREATETABLERESPONSE,
    serialized_options=b'\202\323\344\223\002\030\"\017/v1alpha/tables:\005table',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='DeleteTable',
    full_name='kaskada.api.v1alpha.TableService.DeleteTable',
    index=3,
    containing_service=None,
    input_type=_DELETETABLEREQUEST,
    output_type=_DELETETABLERESPONSE,
    serialized_options=b'\202\323\344\223\002 *\036/v1alpha/tables/{table_name=*}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='LoadData',
    full_name='kaskada.api.v1alpha.TableService.LoadData',
    index=4,
    containing_service=None,
    input_type=_LOADDATAREQUEST,
    output_type=_LOADDATARESPONSE,
    serialized_options=b'\202\323\344\223\002\036\"\031/v1alpha/tables/load_data:\001*',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_TABLESERVICE)

DESCRIPTOR.services_by_name['TableService'] = _TABLESERVICE

# @@protoc_insertion_point(module_scope)
