# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kaskada/prepare/v1alpha/slice.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='kaskada/prepare/v1alpha/slice.proto',
  package='kaskada.prepare.v1alpha',
  syntax='proto3',
  serialized_options=b'\n\033com.kaskada.prepare.v1alphaP\001Z>gitlab.com/kaskada/kaskada/wren/gen/go/kaskada/prepare/v1alpha',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#kaskada/prepare/v1alpha/slice.proto\x12\x17kaskada.prepare.v1alpha\"\x91\x01\n\x0cSliceRequest\x12N\n\x07percent\x18\x01 \x01(\x0b\x32\x32.kaskada.prepare.v1alpha.SliceRequest.PercentSliceH\x00R\x07percent\x1a(\n\x0cPercentSlice\x12\x18\n\x07percent\x18\x01 \x01(\x01R\x07percentB\x07\n\x05sliceB_\n\x1b\x63om.kaskada.prepare.v1alphaP\x01Z>gitlab.com/kaskada/kaskada/wren/gen/go/kaskada/prepare/v1alphab\x06proto3'
)




_SLICEREQUEST_PERCENTSLICE = _descriptor.Descriptor(
  name='PercentSlice',
  full_name='kaskada.prepare.v1alpha.SliceRequest.PercentSlice',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='percent', full_name='kaskada.prepare.v1alpha.SliceRequest.PercentSlice.percent', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='percent', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=201,
)

_SLICEREQUEST = _descriptor.Descriptor(
  name='SliceRequest',
  full_name='kaskada.prepare.v1alpha.SliceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='percent', full_name='kaskada.prepare.v1alpha.SliceRequest.percent', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, json_name='percent', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_SLICEREQUEST_PERCENTSLICE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='slice', full_name='kaskada.prepare.v1alpha.SliceRequest.slice',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=65,
  serialized_end=210,
)

_SLICEREQUEST_PERCENTSLICE.containing_type = _SLICEREQUEST
_SLICEREQUEST.fields_by_name['percent'].message_type = _SLICEREQUEST_PERCENTSLICE
_SLICEREQUEST.oneofs_by_name['slice'].fields.append(
  _SLICEREQUEST.fields_by_name['percent'])
_SLICEREQUEST.fields_by_name['percent'].containing_oneof = _SLICEREQUEST.oneofs_by_name['slice']
DESCRIPTOR.message_types_by_name['SliceRequest'] = _SLICEREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SliceRequest = _reflection.GeneratedProtocolMessageType('SliceRequest', (_message.Message,), {

  'PercentSlice' : _reflection.GeneratedProtocolMessageType('PercentSlice', (_message.Message,), {
    'DESCRIPTOR' : _SLICEREQUEST_PERCENTSLICE,
    '__module__' : 'kaskada.prepare.v1alpha.slice_pb2'
    # @@protoc_insertion_point(class_scope:kaskada.prepare.v1alpha.SliceRequest.PercentSlice)
    })
  ,
  'DESCRIPTOR' : _SLICEREQUEST,
  '__module__' : 'kaskada.prepare.v1alpha.slice_pb2'
  # @@protoc_insertion_point(class_scope:kaskada.prepare.v1alpha.SliceRequest)
  })
_sym_db.RegisterMessage(SliceRequest)
_sym_db.RegisterMessage(SliceRequest.PercentSlice)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
